/**this file uses dec493c,494c, and 495c files and suprinc to create school average files with the following
variables: average gain, avegain (school fixed effects removed); and average gain (school by grade
and individual fixed effects removed).  It also creates data sets with only non-movers, effectively
removing individual fixed effects. It uses squared deviations.**/

set memory 500m
cap log close
log using ${rivkin_home}simba_e/Texas/quality/RESULTS/colldatv,replace

set more off

tempfile temp1m temp1r temp5 temp6 temp7

di "create teacher turnover file"
local grd=5
while `grd'<=7 {

	di "create extract for grade `grd'"

	local yr1=`grd'-1
	local yr2=`yr1'+1
	local yr3=`yr2'+1

	use ${rivkin_home}simba_e/texdata/Texas/teacher/turnov

	keep if grade==`grd' & (mtot9`yr2'9`yr1'>0 | mtot9`yr3'9`yr2'>0 | etot9`yr2'9`yr1'>0 | etot9`yr3'9`yr2'>0)

	keep campus pmsa9`yr3'9`yr2' pmsa9`yr2'9`yr1' pesa9`yr3'9`yr2' pesa9`yr2'9`yr1' /*
	*/ mtot9`yr3'9`yr2' mtot9`yr2'9`yr1' etot9`yr3'9`yr2' etot9`yr2'9`yr1' /*
	*/ sub9`yr3'9`yr2' sub9`yr2'9`yr1' pmgx9`yr2'9`yr1' pegx9`yr2'9`yr1' mchz9`yr2'9`yr1' echz9`yr2'9`yr1' /*
	*/ pmgx9`yr3'9`yr2' pegx9`yr3'9`yr2' mchz9`yr3'9`yr2' echz9`yr3'9`yr2' mcho9`yr3'9`yr2' echo9`yr3'9`yr2' /*
	*/ mcho9`yr2'9`yr1' echo9`yr2'9`yr1'

	foreach x in pmsa mtot pesa etot sub pmgx pegx mchz echz mcho echo {

		di "rename variables"
		rename `x'9`yr2'9`yr1' `x'`grd'`yr2'`grd'`yr1'
		rename `x'9`yr3'9`yr2' `x'`grd'`yr3'`grd'`yr2'
		}

	sort campus
	save `temp`grd''
	clear

	local grd = `grd' + 1
	}

di "merge teacher turnover data sets together

use `temp7'
sort campus
merge campus using `temp6'
tab _m
keep if _m==3 | _m==2

drop _m
sort campus
merge campus using `temp5'
tab _m
keep if _m==3 | _m==1

di "create indicator for no 5th grade"
gen byte grade7m=(mtot5554==0 | mtot5554==.) & (mtot5655==0 | mtot5655==.)
gen byte grade7r=(etot5554==0 | etot5554==.) & (etot5655==0 | etot5655==.)
drop if grade7m~=grade7r
drop grade7r
rename grade7m grade7

sort campus

di "create turnover variables"
	di "first use grades 5 and 6"
	di "math"
	di "create percent all teachers same for grade 5 only"
	gen pmsa594=pmsa5554 if mtot5554>.5
	gen pmsa595=pmsa5655 if mtot5655>.5

	di "create percent gain experience for grade 5 only"
	gen pmgx594=pmgx5554 if mtot5554>.5
	gen pmgx595=pmgx5655 if mtot5655>.5

	di "change in zero yrs experience for grade 5 only"
	gen mchz594=mchz5554 if mtot5554>.5
	gen mchz595=mchz5655 if mtot5655>.5

	di "change in one yr experience for grade 5 only"
	gen mcho594=mcho5554 if mtot5554>.5
	gen mcho595=mcho5655 if mtot5655>.5


	di "create percent all teachers same for 5th and 6th grades combined"
	gen pmsaf594=((mtot5554*pmsa5554)+(mtot6665*pmsa6665))/(mtot5554+mtot6665) /*
	*/ if mtot5554>.5 & mtot6665>.5 & mtot5554~=. & mtot6665~=.

	gen pmsaf595=((mtot5655*pmsa5655)+(mtot6766*pmsa6766))/(mtot5655+mtot6766) /*
	*/ if mtot5655>.5 & mtot6766>.5 & mtot5655~=. & mtot6766~=.

	di "create percent gain experience for 5th and 6th grades combined"
	gen pmgxf594=((mtot5554*pmgx5554)+(mtot6665*pmgx6665))/(mtot5554+mtot6665) /*
	*/ if mtot5554>.5 & mtot6665>.5 & mtot5554~=. & mtot6665~=.

	gen pmgxf595=((mtot5655*pmgx5655)+(mtot6766*pmgx6766))/(mtot5655+mtot6766) /*
	*/ if mtot5655>.5 & mtot6766>.5 & mtot5655~=. & mtot6766~=.

	di "create change in zero years experience for 5th and 6th grades combined"
	gen mchzf594=((mtot5554*mchz5554)+(mtot6665*mchz6665))/(mtot5554+mtot6665) /*
	*/ if mtot5554>.5 & mtot6665>.5 & mtot5554~=. & mtot6665~=.

	gen mchzf595=((mtot5655*mchz5655)+(mtot6766*mchz6766))/(mtot5655+mtot6766) /*
	*/ if mtot5655>.5 & mtot6766>.5 & mtot5655~=. & mtot6766~=.

	di "create change in one years experience for 5th and 6th grades combined"
	gen mchof594=((mtot5554*mcho5554)+(mtot6665*mcho6665))/(mtot5554+mtot6665) /*
	*/ if mtot5554>.5 & mtot6665>.5 & mtot5554~=. & mtot6665~=.

	gen mchof595=((mtot5655*mcho5655)+(mtot6766*mcho6766))/(mtot5655+mtot6766) /*
	*/ if mtot5655>.5 & mtot6766>.5 & mtot5655~=. & mtot6766~=.

	di "english"
	di "create percent all teachers same for grade 5 only"
	gen pesa594=pesa5554 if etot5554>.5
	gen pesa595=pesa5655 if etot5655>.5

	di "create percent gain experience for grade 5 only"
	gen pegx594=pegx5554 if etot5554>.5
	gen pegx595=pegx5655 if etot5655>.5

	di "change in zero yrs experience for grade 5 only"
	gen echz594=echz5554 if etot5554>.5
	gen echz595=echz5655 if etot5655>.5

	di "change in one yr experience for grade 5 only"
	gen echo594=echo5554 if etot5554>.5
	gen echo595=echo5655 if etot5655>.5

	di "create percent all teachers same for 5th and 6th grades combined"
	gen pesaf594=((etot5554*pesa5554)+(etot6665*pesa6665))/(etot5554+etot6665) /*
	*/ if etot5554>.5 & etot6665>.5 & etot5554~=. & etot6665~=.

	gen pesaf595=((etot5655*pesa5655)+(etot6766*pesa6766))/(etot5655+etot6766) /*
	*/ if etot5655>.5 & etot6766>.5 & etot5655~=. & etot6766~=.

	di "create percent gain experience for 5th and 6th grades combined"
	gen pegxf594=((etot5554*pegx5554)+(etot6665*pegx6665))/(etot5554+etot6665) /*
	*/ if etot5554>.5 & etot6665>.5 & etot5554~=. & etot6665~=.

	gen pegxf595=((etot5655*pegx5655)+(etot6766*pegx6766))/(etot5655+etot6766) /*
	*/ if etot5655>.5 & etot6766>.5 & etot5655~=. & etot6766~=.

	di "create change in zero years experience for 5th and 6th grades combined"
	gen echzf594=((etot5554*echz5554)+(etot6665*echz6665))/(etot5554+etot6665) /*
	*/ if etot5554>.5 & etot6665>.5 & etot5554~=. & etot6665~=.

	gen echzf595=((etot5655*echz5655)+(etot6766*echz6766))/(etot5655+etot6766) /*
	*/ if etot5655>.5 & etot6766>.5 & etot5655~=. & etot6766~=.

	di "create change in one year experience for 5th and 6th grades combined"
	gen echof594=((etot5554*echo5554)+(etot6665*echo6665))/(etot5554+etot6665) /*
	*/ if etot5554>.5 & etot6665>.5 & etot5554~=. & etot6665~=.

	gen echof595=((etot5655*echo5655)+(etot6766*echo6766))/(etot5655+etot6766) /*
	*/ if etot5655>.5 & etot6766>.5 & etot5655~=. & etot6766~=.

di "create variables for number of teachers"
di "math"
gen numt594=mtot5554
gen numt595=mtot5655
gen numtf594=(mtot5554+mtot6665)/2
gen numtf595=(mtot5655+mtot6766)/2

replace numt594=. if mtot5554==0 | mtot6665==0
replace numt595=. if mtot5655==0 | mtot6766==0
replace numtf594=. if mtot5554==0 | mtot6665==0
replace numtf595=. if mtot5655==0 | mtot6766==0

di "english"
gen nuet594=etot5554
gen nuet595=etot5655
gen nuetf594=(etot5554+etot6665)/2
gen nuetf595=(etot5655+etot6766)/2

replace nuet594=. if etot5554==0 | etot6665==0
replace nuet595=. if etot5655==0 | etot6766==0
replace nuetf594=. if etot5554==0 | etot6665==0
replace nuetf595=. if etot5655==0 | etot6766==0

gen sub594=sub5554==1 & sub6665==1
gen sub595=sub5655==1 & sub6766==1

gen subf594=sub5554==1 & sub6665==1
gen subf595=sub5655==1 & sub6766==1

di "replace turnover variables with 7th grade values if missing (no 5th grade)"

	di "math"
	di "create percent all teachers same for grade 7 only"
	replace pmsa594=pmsa7776 if pmsa594==. & mtot7776>.5
	replace pmsa595=pmsa7877 if pmsa595==. & mtot7877>.5

	di "create percent all teachers same for 7th and 6th grade combined if missing"
	replace pmsaf594=((mtot7776*pmsa7776)+(mtot6665*pmsa6665))/(mtot7776+mtot6665) /*
	*/ if mtot7776>.5 & mtot6665>.5 & mtot7776~=. & mtot6665~=. & pmsaf594==.

	replace pmsaf595=((mtot7877*pmsa7877)+(mtot6766*pmsa6766))/(mtot7877+mtot6766) /*
	*/ if mtot7877>.5 & mtot6766>.5 & mtot7877~=. & mtot6766~=. & pmsaf595==.

	di "create percent gain experience for grade 7 only"
	replace pmgx594=pmgx7776 if pmgx594==. & mtot7776>.5
	replace pmgx595=pmgx7877 if pmgx595==. & mtot7877>.5

	di "create gain experience for 7th and 6th grade combined if missing"
	replace pmgxf594=((mtot7776*pmgx7776)+(mtot6665*pmgx6665))/(mtot7776+mtot6665) /*
	*/ if mtot7776>.5 & mtot6665>.5 & mtot7776~=. & mtot6665~=. & pmgxf594==.

	replace pmgxf595=((mtot7877*pmgx7877)+(mtot6766*pmgx6766))/(mtot7877+mtot6766) /*
	*/ if mtot7877>.5 & mtot6766>.5 & mtot7877~=. & mtot6766~=. & pmgxf595==.

	di "create change in zero yrs experience for grade 7 only"
	replace mchz594=mchz7776 if mchz594==. & mtot7776>.5
	replace mchz595=mchz7877 if mchz595==. & mtot7877>.5

	di "create change in one yr experience for grade 7 only"
	replace mcho594=mcho7776 if mcho594==. & mtot7776>.5
	replace mcho595=mcho7877 if mcho595==. & mtot7877>.5

	di "create change in zero yrs experience for 7th and 6th grade combined if missing"
	replace mchzf594=((mtot7776*mchz7776)+(mtot6665*mchz6665))/(mtot7776+mtot6665) /*
	*/ if mtot7776>.5 & mtot6665>.5 & mtot7776~=. & mtot6665~=. & mchzf594==.

	replace mchzf595=((mtot7877*mchz7877)+(mtot6766*mchz6766))/(mtot7877+mtot6766) /*
	*/ if mtot7877>.5 & mtot6766>.5 & mtot7877~=. & mtot6766~=. & mchzf595==.

	di "create change in one yr experience for 7th and 6th grade combined if missing"
	replace mchof594=((mtot7776*mcho7776)+(mtot6665*mcho6665))/(mtot7776+mtot6665) /*
	*/ if mtot7776>.5 & mtot6665>.5 & mtot7776~=. & mtot6665~=. & mchof594==.

	replace mchof595=((mtot7877*mcho7877)+(mtot6766*mcho6766))/(mtot7877+mtot6766) /*
	*/ if mtot7877>.5 & mtot6766>.5 & mtot7877~=. & mtot6766~=. & mchof595==.

	di "english"
	di "create percent all teachers same for grade 7 only"
	replace pesa594=pesa7776 if pesa594==. & etot7776>.5
	replace pesa595=pesa7877 if pesa595==. & etot7877>.5

	di "create percent all teachers same for 7th and 6th grade combined if missing"
	replace pesaf594=((etot7776*pesa7776)+(etot6665*pesa6665))/(etot7776+etot6665) /*
	*/ if etot7776>.5 & etot6665>.5 & etot7776~=. & etot6665~=. & pesaf594==.

	replace pesaf595=((etot7877*pesa7877)+(etot6766*pesa6766))/(etot7877+etot6766) /*
	*/ if etot7877>.5 & etot6766>.5 & etot7877~=. & etot6766~=. & pesaf595==.

	di "create percent gain experience for grade 7 only"
	replace pegx594=pegx7776 if pegx594==. & etot7776>.5
	replace pegx595=pegx7877 if pegx595==. & etot7877>.5

	di "create gain experience for 7th and 6th grade combined if missing"
	replace pegxf594=((etot7776*pegx7776)+(etot6665*pegx6665))/(etot7776+etot6665) /*
	*/ if etot7776>.5 & etot6665>.5 & etot7776~=. & etot6665~=. & pegxf594==.

	replace pegxf595=((etot7877*pegx7877)+(etot6766*pegx6766))/(etot7877+etot6766) /*
	*/ if etot7877>.5 & etot6766>.5 & etot7877~=. & etot6766~=. & pegxf595==.

	di "create change in zero yrs experience for grade 7 only"
	replace echz594=echz7776 if echz594==. & etot7776>.5
	replace echz595=echz7877 if echz595==. & etot7877>.5

	di "create change in one yr experience for grade 7 only"
	replace echo594=echo7776 if echo594==. & etot7776>.5
	replace echo595=echo7877 if echo595==. & etot7877>.5

	di "create change in zero years experience for 7th and 6th grade combined if missing"
	replace echzf594=((etot7776*echz7776)+(etot6665*echz6665))/(etot7776+etot6665) /*
	*/ if etot7776>.5 & etot6665>.5 & etot7776~=. & etot6665~=. & echzf594==.

	replace echzf595=((etot7877*echz7877)+(etot6766*echz6766))/(etot7877+etot6766) /*
	*/ if etot7877>.5 & etot6766>.5 & etot7877~=. & etot6766~=. & echzf595==.

	di "create change in one yr experience for 7th and 6th grade combined if missing"
	replace echof594=((etot7776*echo7776)+(etot6665*echo6665))/(etot7776+etot6665) /*
	*/ if etot7776>.5 & etot6665>.5 & etot7776~=. & etot6665~=. & echof594==.

	replace echof595=((etot7877*echo7877)+(etot6766*echo6766))/(etot7877+etot6766) /*
	*/ if etot7877>.5 & etot6766>.5 & etot7877~=. & etot6766~=. & echof595==.

di "replace variables for number of teachers if missing"
di "math"
replace numt594=mtot7776 if numt594==.
replace numt595=mtot7877 if numt595==.
replace numtf594=(mtot7776+mtot6665)/2 if numtf594==.
replace numtf595=(mtot7877+mtot6766)/2 if numtf595==.

replace numt594=. if (mtot7776==0 & mtot5554==0) | mtot6665==0
replace numt595=. if (mtot7877==0 & mtot5655==0) | mtot6766==0
replace numtf594=. if (mtot7776==0 & mtot5554==0)| mtot6665==0
replace numtf595=. if (mtot7877==0 & mtot5655==0) | mtot6766==0

di "english"
replace nuet594=etot7776 if nuet594==.
replace nuet595=etot7877 if nuet595==.
replace nuetf594=(etot7776+etot6665)/2 if nuetf594==.
replace nuetf595=(etot7877+etot6766)/2 if nuetf595==.

replace nuet594=. if (etot7776==0 & etot5554==0) | etot6665==0
replace nuet595=. if (etot7877==0 & etot5655==0) | etot6766==0
replace nuetf594=. if (etot7776==0 & etot5554==0)| etot6665==0
replace nuetf595=. if (etot7877==0 & etot5655==0) | etot6766==0

replace sub594=sub5554==. & sub7776==1 & sub6665==1
replace sub595=sub5655==. & sub7877==1 & sub6766==1

replace subf594=sub5554==. & sub7776==1 & sub6665==1
replace subf595=sub5655==. & sub7877==1 & sub6766==1

drop _m
di "merge information on principal and superintendent turnover"
merge campus using ${rivkin_home}simba_e/texdata/Texas/teacher/suprinc
tab _m
keep if _m==3 | _m==1
drop _m

di "create number of new principals"
gen nunp594=newpr95
gen nunp595=newpr96
gen nunpf594=newpr95 + newpr96
gen nunpf595=newpr96 + newpr97

replace nunp594=newpr97 if grade7==1
replace nunp595=newpr98 if grade7==1
replace nunpf594=newpr97 + newpr96 if grade7==1
replace nunpf595=newpr98 + newpr97 if grade7==1

di "create number of new superintendents"
gen nuns594=newsup95
gen nuns595=newsup96
gen nunsf594=newsup95 + newsup96
gen nunsf595=newsup96 + newsup97

replace nuns594=newsup97 if grade7==1
replace nuns595=newsup98 if grade7==1
replace nunsf594=newsup97 + newsup96 if grade7==1
replace nunsf595=newsup98 + newsup97 if grade7==1

rename campus camp

di "reshaping data set"
reshape groups year 594 595
reshape vars pmsaf pmsa nunp nunpf nuns nunsf sub subf pesa pesaf numt numtf nuet nuetf /*
*/ pmgx pmgxf pegx pegxf mchz mchzf echz echzf mcho mchof echo echof

reshape cons camp grade7
reshape long

sort camp year
save ${rivkin_home}simba_e/texdata/Texas/teacher/corturn,replace


di "merge teacher data with math and reading student test score data files"
di "merge with math files"
di "appending data sets together"
use ${rivkin_home}simba_e/texdata/Texas/quality/dec493c
append using ${rivkin_home}simba_e/texdata/Texas/quality/dec494c
append using ${rivkin_home}simba_e/texdata/Texas/quality/dec495c

di "remove far outliers in terms of campus average gains"
egen msmgai=mean(smgai),by(camp year)
egen numst=count(smgai),by(camp year)

replace msmgai=. if numst<5
sort camp year
quietly by camp year: replace msmgai=. if _n~=_N

foreach x in vargain stdevg difmean bad {
	gen `x'=.
	}

local yr=594
while `yr'<=596 {

	sum msmgai if year==`yr',detail
	replace vargain=r(Var) if year==`yr'
	replace stdevg=sqrt(vargain) if year==`yr'
	replace difmean=abs(msmgai-r(mean)) if year==`yr'
	replace bad=difmean/stdevg>=6 if year==`yr' & msmgai~=.
	list if bad==1 & year==`yr'
	egen byte badcamp=max(bad) if year==`yr',by(camp year)

	drop if badcamp==1
	drop badcamp

	local yr = `yr'+1

	}

local yr=695
while `yr'<=597 {

	sum msmgai if year==`yr',detail
	replace vargain=r(Var) if year==`yr'
	replace stdevg=sqrt(vargain) if year==`yr'
	replace difmean=abs(msmgai-r(mean)) if year==`yr'
	replace bad=difmean/stdevg>=6 if year==`yr' & msmgai~=.
	list if bad==1 & year==`yr'
	egen byte badcamp=max(bad) if year==`yr',by(camp year)

	drop if badcamp==1
	drop badcamp

	local yr = `yr'+1

	}

local yr=796
while `yr'<=798 {

	sum msmgai if year==`yr',detail
	replace vargain=r(Var) if year==`yr'
	replace stdevg=sqrt(vargain) if year==`yr'
	replace difmean=abs(msmgai-r(mean)) if year==`yr'
	replace bad=difmean/stdevg>=6 if year==`yr' & msmgai~=.
	list if bad==1 & year==`yr'
	egen byte badcamp=max(bad) if year==`yr',by(camp year)

	drop if badcamp==1
	drop badcamp

	local yr = `yr'+1

	}


save `temp1m'

di "create indicator for schools with grades 6 and 7 but not 5"
egen byte school5=max(grade5),by(camp)

save ${rivkin_home}simba_e/texdata/Texas/quality/check,replace

tab year school5

di "drop 7th grade observations for schools with 5th grade observations"
drop if (year==796 | year==797 | year==798) & school5==1

di "drop 5th grade observations for schools without 5th grade data"
drop if (year==594 | year==595 | year==596) & school5==0

gen byte grade7=year==796 | year==797 | year==798
egen byte school7=max(grade7),by(camp)

tab school5 school7

di "set grade 7 variable to grade 5 except for grade7 indicator variable"
replace year=594 if year==796
replace year=595 if year==797
replace year=596 if year==798
replace grade5=1 if grade7==1

tab year
tab year grade7

di "create school level data with all observations"
di "collapse data by camp and year"
collapse cohort grade5 grade7 smgai (count) enrol=smgai,by(camp year)
d

di "drop schools with fewer than five observations"
drop if enrol<5
sum,detail

di "remove cohort average gains"
egen cohave=mean(smgai),by(cohort camp)
gen dsgain=smgai-cohave

di "generate squared differences of school averages in successive years"
sort camp year
quietly by camp: gen covsmv=(smgai-smgai[_n+1])*(smgai-smgai[_n+1]) if grade5==1 & grade5[_n+1]==1
quietly by camp: gen covdsv=(dsgain-dsgain[_n+1])*(dsgain-dsgain[_n+1]) if grade5==1 & grade5[_n+1]==1
quietly by camp: gen avenrol=(enrol+enrol[_n+1])/2 if grade5==1 & grade5[_n+1]==1

list in 1/10

keep if year==594 | year==595

di "merging turnover data to test score data"
sort camp year
merge camp year using ${rivkin_home}simba_e/texdata/Texas/teacher/corturn
tab _m
drop _m
sort camp year

di "merging teacher data to test score data'
merge camp year using ${rivkin_home}simba_e/texdata/Texas/teacher/teadata
tab _m
drop _m
sort camp year

di "generate cohort dummy for 594"
gen byte year594=year==594

save ${rivkin_home}simba_e/texdata/Texas/quality/coldatam,replace
d
sum


di "restrict data to stayers"
use `temp1m'
di "create indicator for schools with grades 6 and 7 but not 5"
egen byte school5=max(grade5),by(camp)

tab year school5

di "drop 7th grade observations for schools with 5th grade observations"
drop if (year==796 | year==797 | year==798) & school5==1

gen byte grade7=year==796 | year==797 | year==798
egen byte school7=max(grade7),by(camp)

tab school5 school7

di "set grade 7 variable to grade 5 except for grade7 indicator variable"
replace year=594 if year==796
replace year=595 if year==797
replace year=596 if year==798
replace grade5=1 if grade7==1

tab year
tab year grade7

keep if (stayer6==1 & school7==0) | (stayer7==1 & school7==1)

di "create school level data with all observations"
di "collapse data by camp and year"
collapse cohort grade5 grade7 smgai (count) enrol=smgai,by(camp year)
d

di "drop schools with fewer than 5 observations"
drop if enrol<5
sum smgai,detail

di "remove cohort average gains"
egen cohave=mean(smgai),by(cohort camp)
gen dsgain=smgai-cohave

di "generate squared differences of school averages in successive years"
sort camp year
quietly by camp: gen covsmv=(smgai-smgai[_n+1])*(smgai-smgai[_n+1]) if grade5==1 & grade5[_n+1]==1
quietly by camp: gen covdsv=(dsgain-dsgain[_n+1])*(dsgain-dsgain[_n+1]) if grade5==1 & grade5[_n+1]==1
quietly by camp: gen avenrol=(enrol+enrol[_n+1])/2 if grade5==1 & grade5[_n+1]==1

list in 1/10

keep if year==594 | year==595

di "merging turnover data to test score data"
sort camp year
merge camp year using ${rivkin_home}simba_e/texdata/Texas/teacher/corturn
tab _m
drop _m
sort camp year

di "merging teacher data to test score data'
merge camp year using ${rivkin_home}simba_e/texdata/Texas/teacher/teadata
tab _m
drop _m
sort camp year

di "generate cohort dummy for 594"
gen byte year594=year==594

save ${rivkin_home}simba_e/texdata/Texas/quality/coldatsm,replace
d
sum

di "merge with reading files"
di "appending data sets together"
use ${rivkin_home}simba_e/texdata/Texas/quality/rdec493c
append using ${rivkin_home}simba_e/texdata/Texas/quality/rdec494c
append using ${rivkin_home}simba_e/texdata/Texas/quality/rdec495c

di "remove far outliers in terms of camp average gains"
egen msrgai=mean(srgai),by(camp year)
egen numst=count(srgai),by(camp year)

replace msrgai=. if numst<5
sort camp year
quietly by camp year: replace msrgai=. if _n~=_N

foreach x in vargain stdevg difmean bad {
	gen `x'=.
	}

local yr=594
while `yr'<=596 {

	sum msrgai if year==`yr',detail
	replace vargain=r(Var) if year==`yr'
	replace stdevg=sqrt(vargain) if year==`yr'
	replace difmean=abs(msrgai-r(mean)) if year==`yr'
	replace bad=difmean/stdevg>=6 if year==`yr' & msrgai~=.
	list if bad==1 & year==`yr'
	egen byte badcamp=max(bad) if year==`yr',by(camp year)

	drop if badcamp==1
	drop badcamp

	local yr = `yr'+1

	}

local yr=695
while `yr'<=597 {

	sum msrgai if year==`yr',detail
	replace vargain=r(Var) if year==`yr'
	replace stdevg=sqrt(vargain) if year==`yr'
	replace difmean=abs(msrgai-r(mean)) if year==`yr'
	replace bad=difmean/stdevg>=6 if year==`yr' & msrgai~=.
	list if bad==1 & year==`yr'
	egen byte badcamp=max(bad) if year==`yr',by(camp year)

	drop if badcamp==1
	drop badcamp

	local yr = `yr'+1

	}

local yr=796
while `yr'<=798 {

	sum msrgai if year==`yr',detail
	replace vargain=r(Var) if year==`yr'
	replace stdevg=sqrt(vargain) if year==`yr'
	replace difmean=abs(msrgai-r(mean)) if year==`yr'
	replace bad=difmean/stdevg>=6 if year==`yr' & msrgai~=.
	list if bad==1 & year==`yr'
	egen byte badcamp=max(bad) if year==`yr',by(camp year)

	drop if badcamp==1
	drop badcamp

	local yr = `yr'+1

	}

save `temp1r'

di "create indicator for schools with grades 6 and 7 but not 5"
egen byte school5=max(grade5),by(camp)

tab year school5

di "drop 7th grade observations for schools with 5th grade observations"
drop if (year==796 | year==797 | year==798) & school5==1

gen byte grade7=year==796 | year==797 | year==798
egen byte school7=max(grade7),by(camp)

tab school5 school7

di "set grade 7 variable to grade 5 except for grade7 indicator variable"
replace year=594 if year==796
replace year=595 if year==797
replace year=596 if year==798
replace grade5=1 if grade7==1

tab year
tab year grade7

di "create school level data with all observations"
di "collapse data by camp and year"
collapse cohort grade5 grade7 srgai (count) enrol=srgai,by(camp year)
d

di "drop schools with fewer than 5 observations"
drop if enrol<5

sum,detail

di "remove cohort average gains"
egen cohave=mean(srgai),by(cohort camp)
gen dsgain=srgai-cohave

di "generate squared differences of school averages in successive years"
sort camp year
quietly by camp: gen covsmv=(srgai-srgai[_n+1])*(srgai-srgai[_n+1]) if grade5==1 & grade5[_n+1]==1
quietly by camp: gen covdsv=(dsgain-dsgain[_n+1])*(dsgain-dsgain[_n+1]) if grade5==1 & grade5[_n+1]==1
quietly by camp: gen avenrol=(enrol+enrol[_n+1])/2 if grade5==1 & grade5[_n+1]==1

list in 1/10

keep if year==594 | year==595

di "merging turnover data to test score data"
sort camp year
merge camp year using ${rivkin_home}simba_e/texdata/Texas/teacher/corturn
tab _m
drop _m
sort camp year

di "merging teacher data to test score data'
merge camp year using ${rivkin_home}simba_e/texdata/Texas/teacher/teadata
tab _m
drop _m
sort camp year

di "generate cohort dummy for 594"
gen byte year594=year==594

save ${rivkin_home}simba_e/texdata/Texas/quality/coldatar,replace
d
sum


di "restrict data to stayers"
use `temp1r'

di "create indicator for schools with grades 6 and 7 but not 5"
egen byte school5=max(grade5),by(camp)

tab year school5

di "drop 7th grade observations for schools with 5th grade observations"
drop if (year==796 | year==797 | year==798) & school5==1

gen byte grade7=year==796 | year==797 | year==798
egen byte school7=max(grade7),by(camp)

tab school5 school7

di "set grade 7 variable to grade 5 except for grade7 indicator variable"
replace year=594 if year==796
replace year=595 if year==797
replace year=596 if year==798
replace grade5=1 if grade7==1

tab year
tab year grade7


keep if (stayer6==1 & school7==0) | (stayer7==1 & school7==1)

di "create school level data with all observations"
di "collapse data by camp and year"
collapse cohort grade5 grade7 srgai (count) enrol=srgai,by(camp year)
d

di "drop schools with fewer than 5 observations"
drop if enrol<5

sum,detail

di "remove cohort average gains"
egen cohave=mean(srgai),by(cohort camp)
gen dsgain=srgai-cohave

di "generate squared differences of school averages in successive years"
sort camp year
quietly by camp: gen covsmv=(srgai-srgai[_n+1])*(srgai-srgai[_n+1]) if grade5==1 & grade5[_n+1]==1
quietly by camp: gen covdsv=(dsgain-dsgain[_n+1])*(dsgain-dsgain[_n+1]) if grade5==1 & grade5[_n+1]==1
quietly by camp: gen avenrol=(enrol+enrol[_n+1])/2 if grade5==1 & grade5[_n+1]==1

list in 1/10

keep if year==594 | year==595

di "merging turnover data to test score data"
sort camp year
merge camp year using ${rivkin_home}simba_e/texdata/Texas/teacher/corturn
tab _m
drop _m
sort camp year

di "merging teacher data to test score data'
merge camp year using ${rivkin_home}simba_e/texdata/Texas/teacher/teadata
tab _m
drop _m
sort camp year

di "generate cohort dummy for 594"
gen byte year594=year==594


save ${rivkin_home}simba_e/texdata/Texas/quality/coldatsr,replace
d
sum
