 /**this file regresses the squared deviation in gains between the two classes on teacher turnover.**/

cap log close
log using ${rivkin_home}simba_e/Texas/quality/RESULTS/covregv.log,replace

tempfile tempdat tempnum tempdr tempnr
set more off

di "math"
di "all stayers"
use ${rivkin_home}simba_e/texdata/Texas/quality/coldatsm
tab grade7
sort grade7
by grade7: sum

egen grade7m=max(grade7),by(camp)
replace grade7=grade7m if grade7==.

keep if covdsv~=. 
keep if pmsaf~=. 
keep if nunpf~=. 
keep if mchzf~=. 
keep if nunsf~=. 
keep if avenrol~=. & avenrol~=0 
keep if year594~=. 
keep if grade7~=.

tab grade7

di "create inverse of enrol"
gen ienrol=1/avenrol

di "summarize percent same"
sum pmsa, detail

di "correlate turnover with number of teachers"
cor pmsa numt
cor pmsaf numtf

di "generate % different divided by number of teachers"
gen pdif=(1-pmsa)/numt
gen pdiff=(1-pmsaf)/numtf

di "examine students per teacher"
gen stperte=avenrol/numt
sum stperte,detail

di "generate deviations from school mean"
egen pdiffm=mean(pdiff),by(camp)
egen covdsvm=mean(covdsv),by(camp)

gen pdiffd=pdiff-pdiffm
gen covdsvd=covdsv-covdsvm

sort camp year594
quietly by camp:replace pdiffd=. if year594==0
quietly by camp:replace covdsvd=. if year594==0

sum numt numtf pdif pdiff pdiffd covsmv covdsv covdsvd,detail
sum pmsa pmsaf,detail

gen noturn=pmsa==1
gen noturnf=pmsaf==1

gen allturn=pmsa==0
gen allturnf=pmsaf==0
sum allturn* noturn*

di "generate interaction with grade7"
gen pdif7=pdif*grade7
gen pdiff7=pdiff*grade7
gen echzf7=echzf*grade7


di "MATH TEACHERS"

di "no fixed effects"
regress covsmv pdif nunp nuns year594 ienrol grade7

di "school fixed effects, 6th gain - 5th gain"
regress covdsv pdiff nunpf nunsf year594 ienrol grade7 

di "school by grade fixed effects,dif in 6th gain - 5th gain between cohorts "
areg covdsv pdiff nunpf nunsf year594 ienrol,absorb(camp)

di "include percent gain experience"
di "no fixed effects"
regress covsmv pdif nunp nuns pmgx year594 ienrol grade7

di "school fixed effects, 6th gain - 5th gain"
regress covdsv pdiff nunpf nunsf pmgxf year594 ienrol grade7

di "school by grade fixed effects,dif in 6th gain - 5th gain between cohorts "
areg covdsv pdiff nunpf nunsf pmgxf year594 ienrol,absorb(camp)

di "include change in zero yrs experience"
di "no fixed effects"
regress covsmv pdif nunp nuns mchz year594 ienrol grade7

di "school fixed effects, 6th gain - 5th gain"
regress covdsv pdiff nunpf nunsf mchzf year594 ienrol grade7

di "school by grade fixed effects,dif in 6th gain - 5th gain between cohorts "
areg covdsv pdiff nunpf nunsf mchzf year594 ienrol,absorb(camp)

di "include change in zero yrs experience and one year experience experience data"
di "no fixed effects"
regress covsmv pdif nunp nuns mcho mchz year594 ienrol grade7

di "school fixed effects, 6th gain - 5th gain"
regress covdsv pdiff nunpf nunsf mchof mchzf year594 ienrol grade7

di "school by grade fixed effects,dif in 6th gain - 5th gain between cohorts "
areg covdsv pdiff nunpf nunsf mchof mchzf year594 ienrol,absorb(camp)

di "grade 7 interactions"
regress covsmv pdif pdif7 nunp nuns year594 ienrol grade7
regress covdsv pdiff pdiff7 nunpf nunsf year594 grade7 ienrol
areg covdsv pdiff pdiff7 nunpf nunsf year594 ienrol,absorb(camp)

di "includes change in percent first year"
regress covdsv pdiff pdiff7 echzf echzf7 nunpf nunsf year594 grade7 ienrol
areg covdsv pdiff pdiff7 echzf echzf7 nunpf nunsf year594 ienrol,absorb(camp)


clear

di "reading"
di "all stayers"
use ${rivkin_home}simba_e/texdata/Texas/quality/coldatsr
tab grade7
sort grade7
by grade7: sum

drop if camp==57905163

egen grade7m=max(grade7),by(camp)
replace grade7=grade7m if grade7==.

keep if covdsv~=. & pesaf~=. & nunpf~=. & nunsf~=. & avenrol~=. & avenrol~=0 /*
*/ & year594~=. & grade7~=. & pegxf~=. & echzf~=.
tab grade7

di "create inverse of enrol"
gen ienrol=1/avenrol

di "summarize percent same"
sum pesa, detail

di "correlate turnover with number of teachers"
cor pesa nuet
cor pesaf nuetf

di "generate % different divided by number of teachers"
gen pdif=(1-pesa)/nuet
gen pdiff=(1-pesaf)/nuetf

sum n*

di "examine students per teacher"
gen stperte=avenrol/nuet
sum stperte,detail

di "generate interaction with grade7"
gen pdif7=pdif*grade7
gen pdiff7=pdiff*grade7
gen echzf7=echzf*grade7

di "generate deviations from school mean"
egen pdiffm=mean(pdiff),by(camp)
egen covdsvm=mean(covdsv),by(camp)

gen pdiffd=pdiff-pdiffm
gen covdsvd=covdsv-covdsvm

sum nuet nuetf pdif pdiff pdiffd covsmv covdsv covdsvd,detail
sum pesa pesaf,detail

gen noturn=pesa==1
gen noturnf=pesaf==1

gen allturn=pesa==0
gen allturnf=pesaf==0
sum allturn* noturn*

di "ENGLISH TEACHERS"
di "no fixed effects"
regress covsmv pdif nunp nuns year594 ienrol grade7

di "school fixed effects, 6th gain - 5th gain"
regress covdsv pdiff nunpf nunsf year594 ienrol grade7 

di "school by grade fixed effects,dif in 6th gain - 5th gain between cohorts "
areg covdsv pdiff nunpf nunsf year594 ienrol,absorb(camp)

di "include percent gain experience"
di "no fixed effects"
regress covsmv pdif nunp nuns pegx year594 ienrol grade7

di "school fixed effects, 6th gain - 5th gain"
regress covdsv pdiff nunpf nunsf pegxf year594 ienrol grade7

di "school by grade fixed effects,dif in 6th gain - 5th gain between cohorts "
areg covdsv pdiff nunpf nunsf pegxf year594 ienrol,absorb(camp)

di "include change in zero yrs experience "
di "no fixed effects"
regress covsmv pdif nunp nuns echz year594 ienrol grade7

di "school fixed effects, 6th gain - 5th gain"
regress covdsv pdiff nunpf nunsf echzf year594 ienrol grade7

di "school by grade fixed effects,dif in 6th gain - 5th gain between cohorts "
areg covdsv pdiff nunpf nunsf echzf year594 ienrol,absorb(camp)

di "include change in zero yrs experience and one year experience data"
di "no fixed effects"
regress covsmv pdif nunp nuns echo echz year594 ienrol grade7

di "school fixed effects, 6th gain - 5th gain"
regress covdsv pdiff nunpf nunsf echof echzf year594 ienrol grade7

di "school by grade fixed effects,dif in 6th gain - 5th gain between cohorts "
areg covdsv pdiff nunpf nunsf echof echzf year594 ienrol,absorb(camp)

di "grade 7 interactions"
regress covsmv pdif pdif7 nunp nuns year594 ienrol grade7
regress covdsv pdiff pdiff7 nunpf nunsf year594 grade7 ienrol
areg covdsv pdiff pdiff7 nunpf nunsf year594 ienrol,absorb(camp)

di "includes change in percent zero years experience"
regress covdsv pdiff pdiff7 echzf echzf7 nunpf nunsf year594 grade7 ienrol
areg covdsv pdiff pdiff7 echzf echzf7 nunpf nunsf year594 ienrol,absorb(camp)

