/**This file uses data on a large urban district that links teachers and students by classroom
to examine the degree of differential attrition by observed student gains. Teachers are divided
into thirty quality categories and top and bottom one percent in tails are dropped.**/

cap log close
log using e:\texas\quality\results\difexit30tail.log,replace

set more off
tempfile temp1

use camp avmgain tmove expcat numstud using f:/hisd/tqualdat

keep if numstud>=10
save `temp1'

keep if expcat==1
egen cavgain=mean(avmgain),by(camp)
keep if avmgain~=cavgain

gen difgain=avmgain-cavgain
sum difgain,detail
clear

use `temp1'
egen cavgain=mean(avmgain),by(camp)
gen difgain=avmgain-cavgain

di "set mean = 0"
egen mdifgain=mean(difgain)
replace difgain=difgain-mdifgain

sum difgain, detail

gen maxsc=r(p99)
gen minsc=r(p1)

gen range=r(p99)-r(p1)
gen catsz30=range/30

gen grp30m=.

local grnum = 1
while `grnum'<=30 {

	gen max`grnum' = minsc+(`grnum'*catsz30)
	replace grp30m=`grnum' if grp30m==. & difgain>=minsc & difgain<=max`grnum'

	local grnum = `grnum' + 1
	}



di "replace grnum for the tails"
replace grp30m=0 if difgain<minsc
replace grp30m=31 if difgain>maxsc

gen stay=tmove==1
replace stay=. if tmove==.

gen byte exit=stay==0
replace exit=. if stay==.

di "generate group mean and squared"
egen gmean=mean(difgain),by(grp30m)
gen gmeansq=gmean*gmean


di "generate group percentage stay"
egen pstayg=mean(stay),by(grp30m)

tab exit stay
tab grp30m exit,row col

tab grp30m,sum(difgain)
tab grp30m,sum(gmean)
tab grp30m,sum(stay)
tab grp30m,sum(pstayg)

di "generate group share"
egen tot=count(difgain)
egen gtot=count(difgain),by(grp30m)
gen gshare=gtot/tot

tab grp30m
tab grp30m,sum(gshare)

di "generate contribution to sum of squares"
gen gss=gshare*gmeansq

di "count number of stayers and generate shares"
egen totexit=sum(exit)
egen gtotexit=sum(exit),by(grp30m)
gen gshexit=gtotexit/totexit

tab grp30m if exit==1
tab grp30m if exit==1,sum(gshexit)

di "generate mean and mean squared for exits"

local grnum = 0
while `grnum'<=32 {

	di "generate variable for `grnum' exit share"
	gen share`grnum' = gshare if grp30m==`grnum'
	replace share`grnum' =. if grp30m~=`grnum'
	egen grpsh`grnum'=max(share`grnum')
	
	di "generate variable for `grnum' mean"
	gen mean`grnum' = gmean if grp30m==`grnum'
	replace mean`grnum' =. if grp30m~=`grnum'
	egen grpmean`grnum'=max(mean`grnum')

	di "generate transition probs for total sample"
	gen tprob`grnum'=gshare*grpsh`grnum'

	di "generate transition probs for leavers sample"
	gen prob`grnum'=gshexit*grpsh`grnum'

	di "generate difference in means squared"
	gen dmeansq`grnum'=(grpmean`grnum' - gmean)*(grpmean`grnum' - gmean)

	di "weight by transition share"
	gen gss`grnum' = dmeansq`grnum'*prob`grnum'
	gen tgss`grnum' = dmeansq`grnum'*tprob`grnum'

	local grnum = `grnum' + 1
	}


di "keep one observation per group"
sort grp30m
quietly by grp30m: keep if _N==_n

d
sum
list

di "sum gss contributions for exits across groups"

gen gssall=0
gen tgssall=0

local grnum=0
while `grnum'<=31 {

	replace gssall=gssall+gss`grnum'
	replace tgssall=tgssall+tgss`grnum'

	local grnum = `grnum' + 1
	}

egen varall = sum(gss)
egen totsqexit=sum(gssall)
gen varexit=.5*totsqexit

egen ttotsqexit=sum(tgssall)
gen varalt=.5*ttotsqexit

gen stddevall=sqrt(varall)
gen stddevex=sqrt(varexit)

list
