/**This file uses data on a large urban district that links teachers and students by classroom
to examine the degree of differential attrition by observed student gains. Teachers are divided
into forty quality categories.**/


cap log close
log using e:\texas\quality\results\difexit40.log,replace

set more off
tempfile temp1

use camp avmgain tmove expcat numstud using f:/hisd/tqualdat
sum avmgain,detail
drop if avmgain<=r(p1) | avmgain>r(p99)

keep if numstud>=10
save `temp1'

keep if expcat==1
egen cavgain=mean(avmgain),by(camp)
keep if avmgain~=cavgain

gen difgain=avmgain-cavgain
sum difgain,detail
clear

use `temp1'
egen cavgain=mean(avmgain),by(camp)
gen difgain=avmgain-cavgain

di "set mean = 0"
egen mdifgain=mean(difgain)
replace difgain=difgain-mdifgain

sum difgain, detail

gen maxsc=r(max)
gen minsc=r(min)

gen range=r(max)-r(min)
gen catsz40=range/40

gen grp40m=.

local grnum = 1
while `grnum'<=40 {

	gen max`grnum' = minsc+(`grnum'*catsz40)
	replace grp40m=`grnum' if grp40m==. & difgain>=minsc & difgain<=max`grnum'

	local grnum = `grnum' + 1
	}

drop max*


gen stay=tmove==1
replace stay=. if tmove==.

gen byte exit=stay==0
replace exit=. if stay==.

di "generate group mean and squared"
egen gmean=mean(difgain),by(grp40m)
gen gmeansq=gmean*gmean


di "generate group percentage stay"
egen pstayg=mean(stay),by(grp40m)

tab exit stay
tab grp40m exit,row col

tab grp40m,sum(difgain)
tab grp40m,sum(gmean)
tab grp40m,sum(stay)
tab grp40m,sum(pstayg)

di "generate group share"
egen tot=count(difgain)
egen gtot=count(difgain),by(grp40m)
gen gshare=gtot/tot

tab grp40m
tab grp40m,sum(gshare)

di "generate contribution to sum of squares"
gen gss=gshare*gmeansq

di "count number of stayers and generate shares"
egen totexit=sum(exit)
egen gtotexit=sum(exit),by(grp40m)
gen gshexit=gtotexit/totexit

tab grp40m if exit==1
tab grp40m if exit==1,sum(gshexit)

di "generate mean and mean squared for exits"

local grnum = 1
while `grnum'<=40 {

	di "generate variable for `grnum' exit share"
	gen share`grnum' = gshare if grp40m==`grnum'
	replace share`grnum' =. if grp40m~=`grnum'
	egen grpsh`grnum'=max(share`grnum')
	
	di "generate variable for `grnum' mean"
	gen mean`grnum' = gmean if grp40m==`grnum'
	replace mean`grnum' =. if grp40m~=`grnum'
	egen grpmean`grnum'=max(mean`grnum')

	di "generate transition probs for total sample"
	gen tprob`grnum'=gshare*grpsh`grnum'

	di "generate transition probs for leavers sample"
	gen prob`grnum'=gshexit*grpsh`grnum'

	di "generate difference in means squared"
	gen dmeansq`grnum'=(grpmean`grnum' - gmean)*(grpmean`grnum' - gmean)

	di "weight by transition share"
	gen gss`grnum' = dmeansq`grnum'*prob`grnum'
	gen tgss`grnum' = dmeansq`grnum'*tprob`grnum'

	local grnum = `grnum' + 1
	}


di "keep one observation per group"
sort grp40m
quietly by grp40m: keep if _N==_n

d
sum
list

di "sum gss contributions for exits across groups"

gen gssall=0
gen tgssall=0

local grnum=1
while `grnum'<=40 {

	replace gssall=gssall+gss`grnum'
	replace tgssall=tgssall+tgss`grnum'

	local grnum = `grnum' + 1
	}

egen varall = sum(gss)
egen totsqexit=sum(gssall)
gen varexit=.5*totsqexit

egen ttotsqexit=sum(tgssall)
gen varalt=.5*ttotsqexit

gen stddevall=sqrt(varall)
gen stddevex=sqrt(varexit)

list
