/**this file creates a master data set for teachers. It includes all teachers between grades 0 and 8,
and years 1993-1998. The variables come from the files campus, excetopt, staff
tasppst, employ and pay.NOTE THAT EXPERIENCE IS ATTACHED BY DISTRICT, SO MUST BE SET TO ZERO IF STUD==0**/

set memory 600m
set more off
cap log close
log using ${rivkin_home}simba_e/Texas/quality/RESULTS/masttea193198,replace

forvalues i = 192/198 {
	tempfile temc`i'  teme`i' tems`i'
	}

local daloop=192
while `daloop' <=198 {

     di "using classu`daloop'"

     use $hb_data/TEA/PEIMS/classu/Data/classu`daloop'

     di "create subject and grade variables from service codes provided on tea website"
     gen byte subject=.
     replace subject=12 if service=="02620001" | service=="02620010" | service=="02620020" | service=="02620030" | /*
     */ service=="02620040" | service=="02620050" | /*
     */ service=="02630001" | service=="02630010" | service=="02630020" | service=="02630030" | service=="02630040" | /*
     */ service=="02630050" | service=="02940000" | service=="02560005" | service=="03210530" | /*
     */ service=="02560010" | service=="02560020" | service=="02560030" | service=="02560040" | service=="02560050" | /*
     */ service=="02800000" | service=="02810000" | service=="03200400" | service=="03200500" | service=="03223000" | /*
     */ service=="03223100" | service=="03273200" | service=="03273300" | service=="03273400" | service=="03273500" | /*
     */ service=="03273430" | service=="03273440" | service=="03273450" | /*
     */ service=="03200520" | service=="03200530" | service=="03200540" | service=="03200550" | service=="03273420" | /*
     */ service=="03200510" | service=="03273200" | service=="03273300" | service=="03273410" | service=="03273500"

     replace subject=28 if  service=="02640010" | service=="02640020" | service=="02640030" | service=="02640040" | /*
     */ service=="02640050" | /*
     */ service=="02640060" | service=="02820000" | service=="03103000" | service=="03103100"

     replace subject=16 if service=="02000000" | service=="02010000" | service=="02020000" | service=="02030000" | /*
     */ service=="02040000" | service=="02050000" | service=="02060000" | service=="02070000" | service=="02080000" | /*
     */ service=="01020000"

     gen byte grade=.
     forvalues i=0/8 {

     replace grade=`i' if service=="026400`i'0" | service=="020`i'0000" | service=="026200`i'0" | /* 
     */ service=="026300`i'0" | service=="025600`i'0"
	}

     replace grade = 6 if service=="02800000" | service=="02810000" | service=="02820000" | service=="02940000" | /*
     */ service=="03210530" | service=="03273410" | service=="03200510"
     replace grade = 7 if service=="03103000" | service=="03200400" | service=="03223000" | service=="03273200" | /*
     */ service=="03273400" | service=="03200520" | service=="03200540" | service=="03273420" | service=="03273440"
     replace grade = 8 if service=="03103100" | service=="03200500" | service=="03223100" | service=="03273300" | /*
     */ service=="03273500" | service=="03200530" | service=="03200550" | service=="03273430" | service=="03273450"

     di "kindergarten"
     replace grade=0 if service=="01020000" | service=="02560005" | service=="02620001" | service=="02630001" | service=="02640005"

     di "all elementary not grade specific"
     replace grade=60 if service=="02000000"

     di "add labels"
     label define gradev 60 "elementary k-6"
     label values grade gradev

     label define subjv 12 "ENGLISH" 16 "GENERAL" 28 "MATH"
     label values subject subjv

     keep if role==29 & (grade==1 | grade==2 | grade==3 | grade==4 | grade==5 | grade==6 | grade==7 | /*
     */ grade==8 | grade==60) & (subject==12 | subject==16 | subject==28) & set==80 & popserv==1

     di "compute student average class size for each teacher"

     di "generate class size variable"
     local yrloop=`daloop'-100
     egen stud`yrloop'=mean(students),by(PID campus grade subject)

     egen pfte`yrloop'=sum(pfte),by(PID campus grade subject)

     egen numcl`yrloop'=count(students),by(PID campus grade subject)

     drop students

     sort PID campus grade subject
     quietly by PID campus grade subject: keep if _n==_N

     sort PID campus grade subject

     save `temc`daloop'',replace
     d
     sum

     di "using staff`daloop'"

     use $hb_data/TEA/PEIMS/staff/Data/staff`daloop'

     collapse sex ethnic degree exper,by(PID district)


     gen byte degree`yrloop'=degree
     drop degree

     gen byte exper`yrloop'=exper
     drop exper

     sort PID district

     save `tems`daloop'',replace

     local daloop=`daloop'+ 1

     }


local daloop=192
while `daloop'<=197 {

     local yrloop=`daloop'-100

     di "using employ`daloop'"

     use $hb_data/TEA/PEIMS/employ/Data/employ`daloop'

     collapse (mean) tenure (sum) basepay totalpay FTE,by(PID district)

     gen byte tenure`yrloop'=tenure
     drop tenure
     rename basepay baspay`yrloop'
     rename totalpay totpay`yrloop'
     rename FTE fte`yrloop'

     sort PID district

     save `teme`daloop'',replace

     local daloop = `daloop' + 1
}


local daloop=198
while `daloop'<=198 {

     local yrloop=`daloop'-100

     di "using employ`daloop'"
     use $hb_data/TEA/PEIMS/employ/Data/employ`daloop'

     collapse (mean) tenure (sum) basepay totalpay fte,by(PID district)

     gen byte tenure`yrloop'=tenure
     drop tenure
     rename basepay baspay`yrloop'
     rename totalpay totpay`yrloop'
     rename fte fte`yrloop'

     sort PID district

     save `teme`daloop'',replace

     local daloop = `daloop' + 1
}


di "merging employ data from different years"
use `teme192'
local mrgloop = 193
while `mrgloop'<=198 {

     di "merging employ data `mrgloop' "
     merge PID district using `teme`mrgloop''
     tab _merge
     drop _m
     sort PID district

     local mrgloop=`mrgloop' + 1
}
     sort PID district
     save ${rivkin_home}simba_e/texdata/Texas/teacher/tememp,replace


di "merging staff data from different years"
use `tems192'
local mrgloop = 193
while `mrgloop'<=198 {

     di "merging staff data `mrgloop' "
     merge PID district using `tems`mrgloop''
     tab _merge
     drop _m
     sort PID district

     local mrgloop=`mrgloop' + 1
}

sort PID district
save ${rivkin_home}simba_e/texdata/Texas/teacher/temstaf,replace

di "merging class data from different years"
use `temc192'
local mrgloop = 193
while `mrgloop'<=198 {

     di "merging class data `mrgloop'"
     merge PID campus grade subject using `temc`mrgloop''
     tab _merge
     drop _m
     sort PID campus grade subject

     local mrgloop=`mrgloop' + 1
}

sort PID district
save ${rivkin_home}simba_e/texdata/Texas/teacher/temclas,replace

merge PID district using ${rivkin_home}simba_e/texdata/Texas/teacher/temstaf
tab _m
keep if _m ==3 | _m==1
drop _m
sort PID district

merge PID district using ${rivkin_home}simba_e/texdata/Texas/teacher/tememp
tab _m
keep if _m ==3 | _m==1
drop _m
sort PID


save ${rivkin_home}simba_e/texdata/Texas/teacher/masttea193198,replace
sum
d
