/**this file runs all but the experience decomposition math school fixed effect regressions for the basic paper***/

set maxvar 6000
set matsize 6000
set memory 60g
set more off
cap log close
tempfile temps tempsy tempsy2 tempsg tempcy tempc tempcg tempcy3 tempsy3 tempsy4 tempsg3 tempsgy

log using ${rivkin_home}simba_e/Texas/quality/RESULTS/altmathregs7.log,replace

use ${rivkin_home}simba_e/texdata/Texas/quality/studwk
/*
di "drop schools if there is only one school/grade/year combo"
sort camp
save `tempc'
keep year camp grade
sort camp year grade

di "keep one observation per school-grade-year"
quietly by camp year grade: keep if _n==1

di "drop observations with only one combo"
sort camp
quietly by camp: drop if _N==1

di "keep one observation per campus"
sort camp
quietly by camp: keep if _n==1
keep camp
sort camp

merge camp using `tempc'
tab _m
keep if _m==3
drop _m

di "indicate schools with no movers"
gen byte move=same==0
egen byte anymove=max(move),by(rivid camp)
egen byte sanymove=max(anymove),by(camp)
drop anymove
*/
sort camp
save `temps'

quietly by camp: keep if _n==1
keep camp

di "create campus id"
gen int campid=_n

di "merge with student level data"
sort camp
merge camp using `temps'
tab _m
drop _m

local year year594 year595 year596 year695 year696 year697 year796 year797

sum 
/*
di "student and school fixed effect regression, grade interactions"
felsdvreg smgai disad same pmas pzex poex ptex ptfex stud4 stud5 stud6 stud7, /*
*/ ivar(rivid) jvar(campid) feff(feffc) peff(peffc) xb(xb) res(res) mover(mover) group(group) mnum(mnum)/*
*/ pobs(pobs) robust cluster(camp)

drop xb* res* mover group mnum pobs

outreg disad same pmas pzex poex ptex ptfex stud4 stud5 stud6 stud7 using /*
*/ ${rivkin_home}simba_e/Texas/quality/RESULTS/altmathregs, se nocons noparen nor2 noaster bdec(4) nonotes replace
*/
di "create school by year fixed effects"

di "create acyear variable"
gen int acyear=.
replace acyear=year-(grade*100)

tab year acyear

di "create school by year variable for use with student fixed effects"
sort camp acyear
save `tempsy2'
keep camp acyear
quietly by camp acyear: keep if _n==_N
sort camp acyear

gen int camyr=_n
sort camp acyear
merge camp acyear using `tempsy2'
tab _m
drop _m
/*
di "student and school by year fixed effect regression, grade interactions"
felsdvreg smgai disad same pmas pzex poex ptex ptfex stud4 stud5 stud6 stud7 `year', /*
*/ ivar(rivid) jvar(camyr) feff(feffcy) peff(peffcy) xb(xb) res(res) mover(mover) group(group) mnum(mnum)/*
*/ pobs(pobs) robust cluster(camp)

drop xb* res* mover group mnum pobs
/*
outreg disad same pmas pzex poex ptex ptfex stud4 stud5 stud6 stud7 using /*
*/ ${rivkin_home}simba_e/Texas/quality/RESULTS/altmathregs, se nocons noparen nor2 noaster bdec(4) nonotes append
*/

di "generate interactions for disadvantaged"

foreach x in pzex poex ptex ptfex {
	gen `x'd=`x'*disad
	replace `x'=0 if disad==1
	}

local gr=4
while `gr'<=7 {

	gen studd`gr'=stud`gr'*disad
	replace stud`gr'=0 if disad==1

	local gr=`gr' + 1
	}

di "student and school by year fixed effect regression, grade interactions"
felsdvreg smgai disad same pmas pzex poex ptex ptfex pzexd poexd ptexd ptfexd stud4 stud5 stud6 stud7 /*
*/ studd4 studd5 studd6 studd7 `year', ivar(rivid) jvar(camyr) feff(feffcyd) peff(peffcyd) xb(xb) /*
*/ res(res) mover(mover) group(group) mnum(mnum) pobs(pobs) robust cluster(camp)

drop xb* res* mover group mnum pobs
/*
outreg disad same pmas pzex poex ptex ptfex pzexd poexd ptexd ptfexd stud4 stud5 stud6 stud7 studd4 studd5 studd6 studd7 using /*
*/ ${rivkin_home}simba_e/Texas/quality/RESULTS/altmathregs, se nocons noparen nor2 noaster bdec(4) nonotes append
*/
*/
di "create school by grade variable for use with student fixed effects"

compress
sort camp grade
save `tempsg3'
keep camp grade

quietly by camp grade: keep if _n==1

di "drop one grade per school in making dummies"
sort camp grade
quietly by camp: drop if _n==1

sort camp grade
gen camgr=_n

sort camp grade
merge camp grade using `tempsg3'
tab _m
drop _m

sum camgr,detail
local maxc=r(max)

di "produce dummies"
local i = 1 
while `i'<= `maxc' {
	gen byte dumcg`i'=camgr==`i'
	local i = `i'+1
	}
sum smgai

di "create school grade year varaible"
sort camp year
save `tempsgy'
keep camp year
tab year
sort camp year
quietly by camp year: keep if _n==1
gen campgy=_n
sort camp year
merge camp year using `tempsgy'


di "student, school by year and school by grade fixed effect regression, grade interactions"
felsdvreg smgai disad same pmas pzex poex ptex ptfex stud5 stud6 stud7 `year' dumcg*, /*
*/ ivar(rivid) jvar(camyr) feff(fcycg) peff(pcycg) xb(xb) res(res) mover(mover) group(group) mnum(mnum)/*
*/ pobs(pobs) robust cluster(campgy)

drop xb* res* mover group mnum pobs
/*
outreg disad same pmas pzex poex ptex ptfex stud5 stud6 stud7 using /*
*/ ${rivkin_home}simba_e/Texas/quality/RESULTS/altmathregs, se nocons noparen nor2 noaster bdec(4) nonotes append
*/
