/**this file renames variables for each year using taas data for 1994-1997 (the 4th grade cohort
in 1995).  It then merges data together in order to do descriptive analysis.**/

cap log close
log using e:\texas\quality\results\rdec495c.log,replace

capture program drop rdec495c
program define rdec495c

set more off

di "create tempfiles"
tempfile data495 data596 data697 data798 dat4952 dat5962 dat6972 dat7982
tempfile tempgd tempinc tempcom inddat

local daloop=495
while `daloop' <=596 {

     di "using taas `yrloop'"
     use e:/texdata/texas/raw/texas/student/rtaas`daloop'

     gen byte bil= real(biling)
     drop biling

     di "dropping bilingual and special education students"
     drop if bil==1 | speced==1

     di "creating race-ethnic dummies for grade-year `daloop'"
     gen byte black=ethnic==3
     gen byte hisp=ethnic==1 | ethnic==4
     gen byte asian=ethnic==2

     di "creating disadvantaged dummes for grade-year `daloop'"
     gen byte freel=disadv>=1
     replace freel=. if disadv==.

     di "creating race/ethnic/socio-economic composition variables**/ 
     egen pblk`daloop' = mean(black),by(campus)
     egen phsp`daloop' = mean(hisp),by(campus)
     egen pflu`daloop' = mean(freel),by(campus)
     egen enrol`daloop'=count(campus),by(campus)

     drop black hisp asian 

     di "dropping observations with nonunique ids"
     sort altpid ethnic sex
     quietly by altpid ethnic sex: gen byte numobs=_N
     tab numobs
     drop if numobs>1
     drop numobs

     drop ch1reg migrant gifted esl lep

     di "renaming variables to include year"

     rename campus camp`daloop'
     rename rawred rawre`daloop'
     rename rawmth rawmt`daloop'
     rename rscode rscod`daloop'
     rename mscode mscod`daloop'
     rename disadv disad`daloop'
     rename freel  freel`daloop'
     rename speced spec`daloop'
     rename bil bil`daloop'

     di "set missing observations and bottom 1% of scores to missing"
     sum rawmt`daloop' if mscod`daloop'=="S", detail
     replace rawmt`daloop'=. if mscod`daloop'~="S" | rawmt`daloop'<=_result(16)

     sum rawre`daloop' if rscod`daloop'=="S", detail
     replace rawre`daloop'=. if rscod`daloop'~="S" | rawre`daloop'<=_result(16)

     di "create standardized test scores"
     egen stdmt`daloop'=std(rawmt`daloop')
     egen stdre`daloop'=std(rawre`daloop')

     di "dropping unnecessary variables"
     capture drop month year
     capture drop dname cname rretst mretst
     capture drop rawwrt wscode
     capture drop wretst
     capture drop testlang
     capture drop braille
     capture drop lprint
     drop rscod`daloop' mscod`daloop' grade district

     sort altpid ethnic sex

     save `data`daloop''
     list in 1/10
     d

     local daloop = `daloop' + 101
}

local daloop=697
while `daloop' <=798{

     di "using taas `yrloop'"
     use e:/texdata/texas/raw/texas/student/rtaas`daloop'

     di "dropping bilingual and special education students"
     drop if biling==1 | speced==1

     di "creating race-ethnic dummies for grade-year `daloop'"
     gen byte black=ethnic==3
     gen byte hisp=ethnic==1 | ethnic==4
     gen byte asian=ethnic==2

     di "creating disadvantaged dummes for grade-year `daloop'"
     gen byte freel=economic>=1
     replace freel=. if economic==.

     di "creating race/ethnic/socio-economic composition variables**/ 
     egen pblk`daloop' = mean(black),by(campus)
     egen phsp`daloop' = mean(hisp),by(campus)
     egen pflu`daloop' = mean(freel),by(campus)
     egen enrol`daloop'=count(campus),by(campus)

     di "making sex variable comparable to other files"
     replace sex=sex+1

     drop black hisp asian 

     di "dropping observations with nonunique ids"
     sort altpid ethnic sex 
     quietly by altpid ethnic sex: gen byte numobs=_N
     tab numobs
     drop if numobs>1
     drop numobs

     drop title1 migsta gifted esl lep

     di "renaming variables to include year"

     rename campus camp`daloop'
     rename rawred rawre`daloop'
     rename rawmth rawmt`daloop'
     rename rscode rscod`daloop'
     rename mscode mscod`daloop'
     rename economic disad`daloop'
     rename freel  freel`daloop'
     rename speced spec`daloop'
     rename biling bil`daloop'

     di "set missing observations and bottom 1% of scores to missing"
     sum rawmt`daloop' if mscod`daloop'=="S", detail
     replace rawmt`daloop'=. if mscod`daloop'~="S" | rawmt`daloop'<=_result(16)

     sum rawre`daloop' if rscod`daloop'=="S", detail
     replace rawre`daloop'=. if rscod`daloop'~="S" | rawre`daloop'<=_result(16)

     di "create standardized test scores"
     egen stdmt`daloop'=std(rawmt`daloop')
     egen stdre`daloop'=std(rawre`daloop')

     di "dropping unnecessary variables"
     capture drop month dname cname rretst mretst 
     capture drop year
     capture drop rawwrt wscode
     capture drop wretst
     capture drop testlang
     capture drop braille
     capture drop lprint
     drop rscod`daloop' mscod`daloop' grade

     sort altpid ethnic sex

     save `data`daloop''
     list in 1/10
     d

     local daloop = `daloop' + 101
}

di "merging data sets together"
use `data495'

local mrgloop=596
while `mrgloop'<=798 {

     di "merging data `mrgloop'"
     merge altpid ethnic sex using `data`mrgloop'', update
     tab _merge
     drop _m

     sort altpid ethnic sex
     quietly by altpid ethnic sex: assert _N==1

     local mrgloop=`mrgloop' + 101
}

di "keep if in all three years"
keep if camp596~=. & camp697~=. & camp495~=. & camp798~=.
gen byte strong=1

save `tempgd'
list in 1/10
d

keep altpid
sort altpid
save `inddat'

di "keep unique altids and merge with other data"
di "no merge if sex or ethnic disagree"

local daloop=495
while `daloop' <=798 {

     di "using data `daloop'"
     use `data`daloop''

     di "dropping observations with nonunique ids"
     sort altpid
     quietly by altpid: gen byte numobs=_N
     tab numobs
     drop if numobs>1
     drop numobs

     sort altpid
     save `dat`daloop'2'

     local daloop = `daloop' + 101
}



di "merging data sets together"
use `dat4952'

local mrgloop=596
while `mrgloop'<=798 {

     di "merging data `mrgloop'"
     merge altpid using `dat`mrgloop'2', update
     tab _merge
     keep if _m==3 | _m==4
     drop _m

     sort altpid 

     local mrgloop=`mrgloop' + 101
}

merge altpid using `inddat'
tab _m
keep if _m==1
drop _m
sort altpid


di "keep if in all three years"
keep if camp596~=. & camp697~=. & camp495~=. & camp798~=.
gen byte strong=0

append using `tempgd'
sort altpid ethnic sex
quietly by altpid ethnic sex: assert _N==1
list in 1/10
d

local daloop=596
while `daloop'<=798 {

     di "creating gain scores `yrloop'"
     local prev = `daloop' - 101  

     di "gain in standardized scores and raw scores"
     gen srgai`daloop'=stdre`daloop'-stdre`prev'

     di "standardize gain score"
     sum srgai`daloop',detail
	gen vargain=r(Var)
	gen stdgain=sqrt(vargain)
     replace srgai`daloop'=(srgai`daloop'-r(mean))/stdgain
	drop vargain stdgain


     local daloop=`daloop' + 101
}

drop if srgai697==. | (srgai596==. & srgai798==.)

drop raw* disad* stdre596 stdre697 stdre798 camp495

di "create variable for nonmovers"
gen byte stayer6=camp596==camp697
gen byte stayer7=camp697==camp798

di "create new id variable rivid"
sort altpid ethnic sex birthdat
gen long rivid=$highriv + _n
sum rivid

di "create global macro for highest rivid to use for next cohort"
global highriv = r(max)

reshape groups year 596 697 798
reshape vars camp srgai freel
reshape cons altpid stdre495 stayer6 stayer7 sex ethnic birthdat
reshape long

gen byte grade5=year==596
gen byte cohort=56

save rdec495c,replace

describe
sum

end
