 /**this file renames variables for each year using taas data for 1992-1996 (the 4th grade cohort
in 1993).  It then merges data together in order to do descriptive analysis. Only students in data
in 4th, 5th, 6th and 7th grades are kept.**/

cap log close
log using ${rivkin_home}simba_e/Texas/quality/RESULTS/ren493c.log,replace

capture program drop ren493c
program define ren493c

set more off

di "create tempfiles"
tempfile data392 data493 data594 data695 dat3922 dat4932 dat5942 dat6952 data796 dat7962
tempfile tempgd tempinc tempcom inddat

local daloop=392
while `daloop' <=796 {

     local grloop=int(`daloop'/100)
     local yrloop = `daloop'- ((`grloop'-1)*100)

     di "using taas `yrloop'"
     use biling ethnic economic campus altpid sex rawred rawmth rscode mscode speced /*
     */ using $hb_data/TEA/TAAS/Data/taas`yrloop'_`grloop'

     gen byte bil= biling
     drop biling

     rename economic disadv

     di "creating race-ethnic dummies for grade-year `daloop'"
     gen byte black=ethnic==3
     gen byte hisp=ethnic==1 | ethnic==4
     gen byte asian=ethnic==2

     di "creating disadvantaged dummes for grade-year `daloop'"
     gen byte disad=disadv>=1

     di "creating race/ethnic/socio-economic composition variables**/ 
     egen pblk`daloop' = mean(black),by(campus)
     egen phsp`daloop' = mean(hisp),by(campus)
     egen pflu`daloop' = mean(disad),by(campus)
     egen enrol`daloop'=count(campus),by(campus)

     drop black hisp asian

     di "dropping observations with nonunique ids"
     sort altpid ethnic sex 
     quietly by altpid ethnic sex: gen byte numobs=_N
     tab numobs
     drop if numobs>1
     drop numobs

     di "renaming variables to include year"

     rename campus camp`daloop'
     rename rawred rawre`daloop'
     rename rawmth rawmt`daloop'
     rename rscode rscod`daloop'
     rename mscode mscod`daloop'
     rename disad disad`daloop'
     rename speced spec`daloop'
     rename bil bil`daloop'

     di "set missing observations and bottom 1% of scores to missing"
     sum rawmt`daloop' if mscod`daloop'=="S", detail
     replace rawmt`daloop'=. if mscod`daloop'~="S" | rawmt`daloop'<=_result(16)

     sum rawre`daloop' if rscod`daloop'=="S", detail
     replace rawre`daloop'=. if rscod`daloop'~="S" | rawre`daloop'<=_result(16)

     di "create standardized test scores"
     egen stdmt`daloop'=std(rawmt`daloop')
     egen stdre`daloop'=std(rawre`daloop')

     drop rscod`daloop' mscod`daloop'

     sort altpid ethnic sex

     save `data`daloop''
     list in 1/10
     d

     local daloop = `daloop' + 101
}

di "merging data sets together"
use `data392'

local mrgloop=493
while `mrgloop'<=796 {

     di "merging data `mrgloop'"
     merge altpid ethnic sex using `data`mrgloop'', update
     tab _merge
     drop _m

     sort altpid ethnic sex
     quietly by altpid ethnic sex: assert _N==1

     local mrgloop=`mrgloop' + 101
}

di "keep if in all four years"
keep if camp493~=. & camp594~=. & camp695~=. & camp796~=.
gen byte strong=1

save `tempgd'
list in 1/10
d

keep altpid
sort altpid
save `inddat'

di "keep unique altids and merge with other data"
di "no merge if sex or ethnic disagree"

local daloop=392
while `daloop' <=796 {

     di "using data `daloop'"
     use `data`daloop''

     di "dropping observations with nonunique ids"
     sort altpid
     quietly by altpid: gen byte numobs=_N
     tab numobs
     drop if numobs>1
     drop numobs

     sort altpid
     save `dat`daloop'2'

     local daloop = `daloop' + 101
}



di "merging data sets together"
use `dat3922'

local mrgloop=493
while `mrgloop'<=796 {

     di "merging data `mrgloop'"
     merge altpid using `dat`mrgloop'2', update
     tab _merge
     keep if _m==3 | _m==4
     drop _m

     sort altpid 

     local mrgloop=`mrgloop' + 101
}

merge altpid using `inddat'
tab _m
keep if _m==1
drop _m
sort altpid

gen byte strong=0

append using `tempgd'
sort altpid ethnic sex
quietly by altpid ethnic sex: assert _N==1
list in 1/10
d

di "create gain scores"
local daloop=493
while `daloop'<=796 {

     di "creating gain scores `yrloop'"
     local prev = `daloop' - 101  

     di "gain in standardized scores and raw scores"
     gen smgai`daloop'=stdmt`daloop'-stdmt`prev'
     gen srgai`daloop'=stdre`daloop'-stdre`prev'

     local daloop=`daloop' + 101
}


di "create indicator for same campus in successive years"
gen byte same493=camp392==camp493
gen byte same594=camp493==camp594
gen byte same695=camp594==camp695
gen byte same796=camp695==camp796

sort altpid ethnic sex
quietly by altpid ethnic sex: assert _N==1

di "create new id variable rivid"
sort altpid ethnic sex
gen long rivid=_n
sum rivid

di "create global macro for highest rivid to use for next cohort"
global highriv = r(max)

save ${rivkin_home}simba_e/texdata/Texas/quality/data493c,replace
describe
sum

end

