/**this file creates a data set with student and teacher data for use in education production
function regressions. Only data for regular classrooms are used.*/

capture program drop studteam
program define studteam

set more off
cap log close
log using ${rivkin_home}simba_e/Texas/quality/RESULTS/studteam.log,replace

tempfile temp

di "merge teacher data with student data for appropriate grade/year/subject"

di "create math data sets"
local daloop = 493
while `daloop'<=796 {

     di "creating student data for grade-year `daloop'"
     # delimit ;
     use camp`daloop'  smgai`daloop' spec`daloop' pflu`daloop' pblk`daloop' phsp`daloop' enrol`daloop'
     bil`daloop' stdmt`daloop' disad`daloop' ethnic sex same`daloop' rivid using ${rivkin_home}simba_e/texdata/Texas/quality/data493c ;
     #delimit cr

     gen long district=int(camp`daloop'/1000)
     sort district
     merge district using ${rivkin_home}simba_e/texdata/Texas/disttype
     tab _m
     drop if _m==2
     drop _m

     di "creating district type dummies for grade-year `daloop'"
     gen byte lcity`daloop'=type==3
     gen byte scity`daloop'=type==7
     gen byte sub`daloop'=type==2 | type==6

     sort district
     save `temp',replace

     di "creating count for campuses in a district"
     sort district
     collapse district,by(camp`daloop')
     collapse (count) numc`daloop'=camp`daloop',by(district)
     sort district
     merge district using `temp'
     drop _m district type disttype 

     di "creating race-ethnic dummies for grade-year `daloop'"
     gen byte black`daloop'=ethnic==3
     gen byte hisp`daloop'=ethnic==1 | ethnic==4
     gen byte asian`daloop'=ethnic==2

     di "dropping missing test scores, bilingual and special ed"
     drop if smgai`daloop'==. | bil`daloop'==1 | spec`daloop'==1

     sort camp`daloop'

     di "merging teacher and student data for grade-year `daloop'"

     di "first merge with data for math teachers"
     merge camp`daloop' using ${rivkin_home}simba_e/texdata/Texas/teacher/mtht`daloop'
     tab _m
     drop _m
     sort camp`daloop'

     di "merge with data for all teachers, obs with missing teacher data receive new info"
     merge camp`daloop' using ${rivkin_home}simba_e/texdata/Texas/teacher/allt`daloop',update replace
     tab _m
     drop _m

     di "set stud to missing if stud<10"
     replace stud=. if stud<10

     save ${rivkin_home}simba_e/texdata/Texas/quality/mstea`daloop',replace

     local daloop = `daloop' + 101
}

local daloop = 494
while `daloop'<=797 {

     di "creating student data for grade-year `daloop'"
     # delimit ;
     use camp`daloop' smgai`daloop' spec`daloop' pflu`daloop' pblk`daloop' phsp`daloop' enrol`daloop'
     bil`daloop' stdmt`daloop' disad`daloop' ethnic sex same`daloop' rivid using ${rivkin_home}simba_e/texdata/Texas/quality/data494c ;
     #delimit cr

     gen long district=int(camp`daloop'/1000)
     sort district
     merge district using ${rivkin_home}simba_e/texdata/Texas/disttype
     tab _m
     drop if _m==2
     drop _m

     di "creating district type dummies for grade-year `daloop'"
     gen byte lcity`daloop'=type==3
     gen byte scity`daloop'=type==7
     gen byte sub`daloop'=type==2 | type==6

     sort district
     save `temp',replace

     di "creating count for campuses in a district"
     sort district
     collapse district,by(camp`daloop')
     collapse (count) numc`daloop'=camp`daloop',by(district)
     sort district
     merge district using `temp'
     drop _m district type disttype 

     di "creating race-ethnic dummies for grade-year `daloop'"
     gen byte black`daloop'=ethnic==3
     gen byte hisp`daloop'=ethnic==1 | ethnic==4
     gen byte asian`daloop'=ethnic==2

     di "dropping missing test scores, bilingual and special ed"
     drop if smgai`daloop'==. | bil`daloop'==1 | spec`daloop'==1

     sort camp`daloop'

     di "merging teacher and student data for grade-year `daloop'"

     di "first merge with data for math teachers"
     merge camp`daloop' using ${rivkin_home}simba_e/texdata/Texas/teacher/mtht`daloop'
     tab _m
     drop _m
     sort camp`daloop'

     di "merge with data for all teachers, obs with missing teacher data receive new info"
     merge camp`daloop' using ${rivkin_home}simba_e/texdata/Texas/teacher/allt`daloop',update replace
     tab _m
     drop _m

     di "set stud to missing if stud<10"
     replace stud=. if stud<10

     save ${rivkin_home}simba_e/texdata/Texas/quality/mstea`daloop',replace

     local daloop = `daloop' + 101
}

local daloop = 495
while `daloop'<=697 {

     di "creating student data for grade-year `daloop'"
     # delimit ;
     use camp`daloop' smgai`daloop' spec`daloop' pflu`daloop' pblk`daloop' phsp`daloop' enrol`daloop'
     bil`daloop' stdmt`daloop' disad`daloop' ethnic sex same`daloop' rivid using ${rivkin_home}simba_e/texdata/Texas/quality/data495c ;
     #delimit cr

     gen long district=int(camp`daloop'/1000)
     sort district
     merge district using ${rivkin_home}simba_e/texdata/Texas/disttype
     tab _m
     drop if _m==2
     drop _m

     di "creating district type dummies for grade-year `daloop'"
     gen byte lcity`daloop'=type==3
     gen byte scity`daloop'=type==7
     gen byte sub`daloop'=type==2 | type==6

     sort district
     save `temp',replace

     di "creating count for campuses in a district"
     sort district
     collapse district,by(camp`daloop')
     collapse (count) numc`daloop'=camp`daloop',by(district)
     sort district
     merge district using `temp'
     drop _m district type disttype 

     di "creating race-ethnic dummies for grade-year `daloop'"
     gen byte black`daloop'=ethnic==3
     gen byte hisp`daloop'=ethnic==1 | ethnic==4
     gen byte asian`daloop'=ethnic==2

     di "dropping missing test scores, bilingual and special ed"
     drop if smgai`daloop'==. | bil`daloop'==1 | spec`daloop'==1

     sort camp`daloop'

     di "merging teacher and student data for grade-year `daloop'"

     di "first merge with data for math teachers"
     merge camp`daloop' using ${rivkin_home}simba_e/texdata/Texas/teacher/mtht`daloop'
     tab _m
     drop _m
     sort camp`daloop'

     di "merge with data for all teachers, obs with missing teacher data receive new info"
     merge camp`daloop' using ${rivkin_home}simba_e/texdata/Texas/teacher/allt`daloop',update replace
     tab _m
     drop _m

     di "set stud to missing if stud<10"
     replace stud=. if stud<10

     save ${rivkin_home}simba_e/texdata/Texas/quality/mstea`daloop',replace

     local daloop = `daloop' + 101
}

end
