/**this file creates a data set on teachers for use in education production function regressions.
The variables come from masttea2. Observations may be excluded if there is bad data, or fixed
values may be used. SUMS ARE NOT WEIGHTED*USE ONLY UP TO 1998 RIGHT NOW*/

capture program drop teavar1
program define teavar1

forvalues i = 193/198 {

	tempfile tem4`i' tem5`i' tem6`i' tem7`i'
	}

set memory 900m
set more off
cap log close
log using ${rivkin_home}simba_e/Texas/quality/RESULTS/teavar1.log,replace

di "using masttea2"

use ${rivkin_home}simba_e/texdata/Texas/teacher/masttea2

local yrloop=93
while `yrloop' <=98 {

     di "setting variables to missing in `yrloop' if stud`yrloop' = missing"
     replace exper`yrloop'=. if stud`yrloop'==.
     replace degree`yrloop'=. if stud`yrloop'==.
     replace pfte`yrloop'=. if stud`yrloop'==.
     replace numcl`yrloop'=. if stud`yrloop'==.

     di "set stud to missing if >35"
     replace stud`yrloop'=. if stud`yrloop'>35

     di "create indicator for first year teachers"
     gen byte zexp`yrloop'=exper`yrloop'==0
     replace zexp`yrloop'=. if exper`yrloop'==.

     di "create indicator for second year teachers"
     gen byte oexp`yrloop'=exper`yrloop'==1
     replace oexp`yrloop'=. if exper`yrloop'==.

     di "create indicator for third year teachers"
     gen byte texp`yrloop'=exper`yrloop'==2
     replace texp`yrloop'=. if exper`yrloop'==.

     di "create indicator for 4th-5th year teachers"
     gen byte tfexp`yrloop'=exper`yrloop'==3 | exper`yrloop'==4
     replace tfexp`yrloop'=. if exper`yrloop'==.

     di "create indicator for 6th-10th year teachers"

     #delimit ;
     gen byte fnexp`yrloop'=exper`yrloop'==5 | exper`yrloop'==6 | exper`yrloop'==7 |
     exper`yrloop'==8 | exper`yrloop'==9 ; 
     #delimit cr
     replace fnexp`yrloop'=. if exper`yrloop'==.

     di "create indicator for 21st-30th year teachers"
     gen byte twexp`yrloop'=exper`yrloop'>19 & exper`yrloop'<30
     replace twexp`yrloop'=. if exper`yrloop'==.

     di "create indicator for >30th year teachers"
     gen byte thexp`yrloop'=exper`yrloop'>29
     replace thexp`yrloop'=. if exper`yrloop'==.

     di "create indicator for graduate degree"
     gen byte hdeg`yrloop'=degree`yrloop'>=2
     replace hdeg`yrloop'=. if degree`yrloop'==.

     di "create indicator for black teacher"
     gen byte blktea`yrloop'=ethnic==3
     replace blktea`yrloop'=. if ethnic==. | stud`yrloop'==.

     di "create indicator for hispanic teacher"
     gen byte hsptea`yrloop'=ethnic==4
     replace hsptea`yrloop'=. if ethnic==. | stud`yrloop'==.

     local yrloop = `yrloop' + 1
}


di "reshape data"
reshape groups year 93 94 95 96 97 98
reshape vars zexp oexp texp tfexp fnexp twexp thexp hdeg pfte stud numcl exper blktea hsptea
reshape cons PID campus grade subject
reshape query  
reshape long  


di "collapsing data by campus, grade, subject, and year"

collapse (rawsum) pfte numcl (mean) zexp oexp texp tfexp fnexp twexp thexp  /*
*/ hdeg stud exper blktea hsptea (count) numtea=stud,by(campus grade subject year)

di "setting variables to missing if experience is missing"
replace hdeg=. if exper==.
replace zexp=. if exper==.
replace oexp=. if exper==.
replace texp=. if exper==.
replace tfexp=. if exper==.
replace fnexp=. if exper==.
replace twexp=. if exper==.
replace thexp=. if exper==.
replace blktea=. if exper==.
replace hsptea=. if exper==.

di "create shares"
rename hdeg pmas
rename zexp pzex
rename oexp poex
rename texp ptex
rename tfexp ptfex
rename fnexp pfnex
rename twexp ptwex
rename thexp pthex
rename blktea pblktea
rename hsptea phsptea

sort campus grade year subject
save ${rivkin_home}simba_e/texdata/Texas/teacher/tbycgs,replace
sum,detail


di "collapsing data by campus, grade, and year for general and math teachers"
drop if subject==12

collapse (rawsum) numtea numcl pfte (mean) pzex poex ptex ptfex pfnex ptwex pthex pmas /*
*/ stud exper pblktea phsptea [fweight=numtea], by(campus grade year)

di "setting variables to missing if experience is missing"
replace pmas=. if exper==.
replace pzex=. if exper==.
replace poex=. if exper==.
replace ptex=. if exper==.
replace ptfex=. if exper==.
replace pfnex=. if exper==.
replace ptwex=. if exper==.
replace pthex=. if exper==.
replace pblktea=. if exper==.
replace phsptea=. if exper==.

sort campus grade year

save ${rivkin_home}simba_e/texdata/Texas/teacher/tbycg,replace


di "add enrollment data and create pupil/teacher ratios"


local yrloop=194
while `yrloop'<=198 {

	local grloop=4
	while `grloop'<=7 {

		use campus using $hb_data/TEA/TAAS/Data/taas`yrloop'_`grloop'
		gen long district=int(campus/1000)
		collapse (count) enrol=district,by(campus)
		gen byte grade=`grloop'
		gen int year = `yrloop'- 100
		save `tem`grloop'`yrloop''

		local grloop = `grloop' + 1
		}

	local yrloop = `yrloop' + 1
	}

use `tem4194'

forvalues i = 195/198 {
	append using `tem4`i''
	}

di "append data sets together"
local gr = 5
while `gr'<=7 {

	local yr = 194
	while `yr'<=198 {

		append using `tem`gr'`yr''

		local yr = `yr'+1
		}

	local gr = `gr'+1
	}

sort campus grade year
save ${rivkin_home}simba_e/texdata/Texas/teacher/enroldat,replace
d
tab year grade, row col
sum

di "merge enrollment data with teacher data"
use ${rivkin_home}simba_e/texdata/Texas/teacher/tbycgs
merge campus grade year using ${rivkin_home}simba_e/texdata/Texas/teacher/enroldat
tab _m
drop _m

di "determine whether to use subject specific data"
di "generate pupil/teacher and class ratios by subject"
gen pupntm=enrol/numtea if subject==28
gen pupncm=enrol/numcl if subject==28

gen pupntg=enrol/numtea if subject==16
gen pupncg=enrol/numcl if subject==16

egen pupnumtm=max(pupntm),by(campus year grade)
egen pupnumcm=max(pupncm),by(campus year grade)

egen pupnumtg=max(pupntg),by(campus year grade)
egen pupnumcg=max(pupncg),by(campus year grade)

di "generate indicators for subject taught"
gen byte mathtea=0
gen byte gentea=0

replace mathtea=1 if stud~=. & subject==28
replace gentea=1 if stud~=. & subject==16

egen math=max(mathtea),by(campus year grade)
egen general=max(gentea),by(campus year grade)

di "generate stud by subject"
gen studmth=stud if subject==28
gen studgen=stud if subject==16

egen studm=max(studmth),by(campus year grade)
egen studg=max(studgen),by(campus year grade)


di "categorize schools: subject specific if no general teachers or math teacher data consistent"
gen byte subspec=.
replace subspec=0 if (math==. | math==0) & general==1
replace subspec=1 if math==1 & (general==0 | general==.) & subspec==.
replace subspec=1 if math==1 & ((pupnumtm<=40 & abs(pupnumtm-studm)<=5) /*
*/ | (pupnumcm<=40 & abs(pupnumcm-studm)<=5)) & subspec==.

replace subspec=11 if math==1 & (pupnumtm<=200 & pupnumtm>=10) & subspec==.
replace subspec=0 if general==1 & (pupnumtg<=40 & abs(pupnumtg-studg)<=5) & subspec==.
replace subspec=10 if general==1 & (pupnumtg<=40 & pupnumtg>=10) & subspec==.
replace subspec=12 if subspec==. | (enrol<5 | enrol==.)

di "check for sum of general and math teachers for those with subspec==11 or 10 or 12"
replace stud=. if subject==12
replace numtea=. if subject==12
replace numcl=. if subject==12

tab subspec,sum(enrol)

list in 1/100 if (grade==5 | grade==6) & year>=95
collapse (mean) math general subspec stud enrol (rawsum) numtea numcl [fweight=numcl],by(campus grade year)
gen puptea=enrol/numtea
gen pupcl=enrol/numcl

tab subspec,sum(enrol)
replace subspec=2 if (subspec==11 | subspec==10 | subspec==12) & enrol>=5 & (abs(puptea-stud)<=5 | abs(pupcl-stud)<=5)
replace subspec=1 if subspec==11
replace subspec=0 if subspec==10

keep subspec campus grade year enrol
sort campus grade year

tab subspec if (grade==5 | grade==6 | grade==7) & (year==95 | year==96 | year==97) & enrol~=.
keep if grade>=4 & grade<=8 & year>=93 & year<=98
save ${rivkin_home}simba_e/texdata/Texas/teacher/subspeci,replace
list in 1/10


di "collapsing data by campus, grade, and year for general and reading teachers"
use ${rivkin_home}simba_e/texdata/Texas/teacher/tbycgs
drop if subject==28

collapse (rawsum) numtea numcl pfte (mean) pzex poex ptex ptfex pfnex ptwex pthex pmas /*
*/ stud exper pblktea phsptea [fweight=numtea], by(campus grade year)

di "setting variables to missing if experience is missing"
replace pmas=. if exper==.
replace pzex=. if exper==.
replace poex=. if exper==.
replace ptex=. if exper==.
replace ptfex=. if exper==.
replace pfnex=. if exper==.
replace ptwex=. if exper==.
replace pthex=. if exper==.
replace pblktea=. if exper==.
replace phsptea=. if exper==.


sort campus grade year

save ${rivkin_home}simba_e/texdata/Texas/teacher/rtbycg,replace

end
