/**this file creates a data set on teachers for use in education production function regressions.
The variables come from masttea2. Observations may be excluded if there is bad data, or fixed
values may be used. SUMS ARE NOT WEIGHTED*USE ONLY UP TO 1998 RIGHT NOW*/

forvalues i = 193/198 {

	tempfile tem4`i' tem5`i' tem6`i' tem7`i'
	}

set memory 900m
set more off
cap log close
log using ${rivkin_home}simba_e/Texas/quality/RESULTS/teavar1ss.log,replace
tempfile tempss

di "using masttea2"

use ${rivkin_home}simba_e/texdata/Texas/teacher/masttea2

local yrloop=93
while `yrloop' <=98 {

     di "setting variables to missing in `yrloop' if stud`yrloop' = missing"
     replace exper`yrloop'=. if stud`yrloop'==.
     replace degree`yrloop'=. if stud`yrloop'==.
     replace pfte`yrloop'=. if stud`yrloop'==.
     replace numcl`yrloop'=. if stud`yrloop'==.

     di "set stud to missing if >35"
     replace stud`yrloop'=. if stud`yrloop'>35

     di "create indicator for first year teachers"
     gen byte zexp`yrloop'=exper`yrloop'==0
     replace zexp`yrloop'=. if exper`yrloop'==.

     di "create indicator for second year teachers"
     gen byte oexp`yrloop'=exper`yrloop'==1
     replace oexp`yrloop'=. if exper`yrloop'==.

     di "create indicator for third year teachers"
     gen byte texp`yrloop'=exper`yrloop'==2
     replace texp`yrloop'=. if exper`yrloop'==.

     di "create indicator for 4th-5th year teachers"
     gen byte tfexp`yrloop'=exper`yrloop'==3 | exper`yrloop'==4
     replace tfexp`yrloop'=. if exper`yrloop'==.

     di "create indicator for 6th-10th year teachers"

     #delimit ;
     gen byte fnexp`yrloop'=exper`yrloop'==5 | exper`yrloop'==6 | exper`yrloop'==7 |
     exper`yrloop'==8 | exper`yrloop'==9 ; 
     #delimit cr
     replace fnexp`yrloop'=. if exper`yrloop'==.

     di "create indicator for 21st-30th year teachers"
     gen byte twexp`yrloop'=exper`yrloop'>19 & exper`yrloop'<30
     replace twexp`yrloop'=. if exper`yrloop'==.

     di "create indicator for >30th year teachers"
     gen byte thexp`yrloop'=exper`yrloop'>29
     replace thexp`yrloop'=. if exper`yrloop'==.

     di "create indicator for graduate degree"
     gen byte hdeg`yrloop'=degree`yrloop'>=2
     replace hdeg`yrloop'=. if degree`yrloop'==.

     di "create indicator for black teacher"
     gen byte blktea`yrloop'=ethnic==3
     replace blktea`yrloop'=. if ethnic==. | stud`yrloop'==.

     di "create indicator for hispanic teacher"
     gen byte hsptea`yrloop'=ethnic==4
     replace hsptea`yrloop'=. if ethnic==. | stud`yrloop'==.

     local yrloop = `yrloop' + 1
}


di "reshape data"
reshape groups year 93 94 95 96 97 98
reshape vars zexp oexp texp tfexp fnexp twexp thexp hdeg pfte stud numcl exper blktea hsptea
reshape cons PID campus grade subject
reshape query  
reshape long  

save `tempss'

di "collapsing data by campus, grade and year if not english"
drop if subject==12

collapse (rawsum) pfte numcl (mean) zexp oexp texp tfexp fnexp twexp thexp  /*
*/ hdeg stud exper blktea hsptea,by(PID campus grade year)

collapse (rawsum) pfte numcl (mean) zexp oexp texp tfexp fnexp twexp thexp  /*
*/ hdeg stud exper blktea hsptea (count) numtea=stud,by(campus grade year)

di "setting variables to missing if experience is missing"
replace hdeg=. if exper==.
replace zexp=. if exper==.
replace oexp=. if exper==.
replace texp=. if exper==.
replace tfexp=. if exper==.
replace fnexp=. if exper==.
replace twexp=. if exper==.
replace thexp=. if exper==.
replace blktea=. if exper==.
replace hsptea=. if exper==.

di "create shares"
rename hdeg pmas
rename zexp pzex
rename oexp poex
rename texp ptex
rename tfexp ptfex
rename fnexp pfnex
rename twexp ptwex
rename thexp pthex
rename blktea pblktea
rename hsptea phsptea

sort campus grade year
save ${rivkin_home}simba_e/texdata/Texas/teacher/tbycgss,replace
sum,detail
clear

di "reading"
di "collapsing data by campus, grade and year if not math"
use `tempss'
drop if subject==28

collapse (rawsum) pfte numcl (mean) zexp oexp texp tfexp fnexp twexp thexp  /*
*/ hdeg stud exper blktea hsptea,by(PID campus grade year)

collapse (rawsum) pfte numcl (mean) zexp oexp texp tfexp fnexp twexp thexp  /*
*/ hdeg stud exper blktea hsptea (count) numtea=stud,by(campus grade year)

di "setting variables to missing if experience is missing"
replace hdeg=. if exper==.
replace zexp=. if exper==.
replace oexp=. if exper==.
replace texp=. if exper==.
replace tfexp=. if exper==.
replace fnexp=. if exper==.
replace twexp=. if exper==.
replace thexp=. if exper==.
replace blktea=. if exper==.
replace hsptea=. if exper==.

di "create shares"
rename hdeg pmas
rename zexp pzex
rename oexp poex
rename texp ptex
rename tfexp ptfex
rename fnexp pfnex
rename twexp ptwex
rename thexp pthex
rename blktea pblktea
rename hsptea phsptea

sort campus grade year
save ${rivkin_home}simba_e/texdata/Texas/teacher/rtbycgss,replace
sum,detail

