/**this file creates a data set with student and teacher data for use in education production
function regressions. Only data for regular classrooms are used.*/

capture program drop teavar2
program define teavar2

set more off
cap log close
log using ${rivkin_home}simba_e/Texas/quality/RESULTS/teavar2.log,replace

/**create teacher data sets for each year/grade. Four data sets are created 1) all math and general teachers;
2) all english and general teachers; 3) math teachers; and 4) english teachers.**/

di "create data sets for all math and general teachers"
local grloop = 3
while `grloop'<=7 {

     local yrloop=93
     while `yrloop' <=98 {

          di "using data for `grloop'th grade in `yrloop'"
          use ${rivkin_home}simba_e/texdata/Texas/teacher/tbycg
          keep if grade==`grloop' & year==`yrloop'

	  di "rename variables"
          rename pmas pmas`grloop'`yrloop'
          rename pzex pzex`grloop'`yrloop'
          rename poex poex`grloop'`yrloop'
          rename ptex ptex`grloop'`yrloop'
          rename ptfex ptfex`grloop'`yrloop'
          rename pfnex pfnex`grloop'`yrloop'
          rename ptwex ptwex`grloop'`yrloop'
          rename pthex pthex`grloop'`yrloop'
          rename campus camp`grloop'`yrloop'
          rename exper exper`grloop'`yrloop'
          rename stud stud`grloop'`yrloop'
          rename numtea numt`grloop'`yrloop'

          #delimit ;
          keep camp`grloop'`yrloop' exper`grloop'`yrloop' stud`grloop'`yrloop'
          pmas`grloop'`yrloop' pzex`grloop'`yrloop' numt`grloop'`yrloop'
          poex`grloop'`yrloop' ptex`grloop'`yrloop' ptfex`grloop'`yrloop'
          pfnex`grloop'`yrloop' ptwex`grloop'`yrloop' pthex`grloop'`yrloop' ;

          #delimit cr

          sort camp`grloop'`yrloop'
	  quietly by camp`grloop'`yrloop': assert _N==1

          save ${rivkin_home}simba_e/texdata/Texas/teacher/allt`grloop'`yrloop',replace
	  clear

          local yrloop = `yrloop' + 1
     }

     local grloop = `grloop' + 1
}

di "create data sets for all english and general teachers"
local grloop = 3
while `grloop'<=7 {

     local yrloop=93
     while `yrloop' <=98 {

          di "using data for `grloop'th grade in `yrloop'"
          use ${rivkin_home}simba_e/texdata/Texas/teacher/rtbycg
          keep if grade==`grloop' & year==`yrloop'

	  di "rename variables"
          rename pmas pmas`grloop'`yrloop'
          rename pzex pzex`grloop'`yrloop'
          rename poex poex`grloop'`yrloop'
          rename ptex ptex`grloop'`yrloop'
          rename ptfex ptfex`grloop'`yrloop'
          rename pfnex pfnex`grloop'`yrloop'
          rename ptwex ptwex`grloop'`yrloop'
          rename pthex pthex`grloop'`yrloop'
          rename campus camp`grloop'`yrloop'
          rename exper exper`grloop'`yrloop'
          rename stud stud`grloop'`yrloop'
          rename numtea numt`grloop'`yrloop'

          #delimit ;
          keep camp`grloop'`yrloop' exper`grloop'`yrloop' stud`grloop'`yrloop'
          pmas`grloop'`yrloop' pzex`grloop'`yrloop' numt`grloop'`yrloop'
          poex`grloop'`yrloop' ptex`grloop'`yrloop' ptfex`grloop'`yrloop'
          pfnex`grloop'`yrloop' ptwex`grloop'`yrloop' pthex`grloop'`yrloop' ;

          #delimit cr

          sort camp`grloop'`yrloop'
	  quietly by camp`grloop'`yrloop': assert _N==1

          save ${rivkin_home}simba_e/texdata/Texas/teacher/rallt`grloop'`yrloop',replace
	  clear

          local yrloop = `yrloop' + 1
     }

     local grloop = `grloop' + 1
}


di "create data sets for math teachers for grades 4-7"
local grloop = 4
while `grloop'<=7 {

     local yrloop=93
     while `yrloop' <=96 {

          di "using data for `grloop'th grade in `yrloop'"
          use ${rivkin_home}simba_e/texdata/Texas/teacher/tbycgs
          keep if grade==`grloop' & subject==28 & numtea>0 & numtea~=. & year==`yrloop'

	  di "merge with subject specialty data, set nonspecialty schools to missing"
	  sort camp grade year
	  merge camp grade year using ${rivkin_home}simba_e/texdata/Texas/teacher/subspeci
	  tab _m
	  keep if _m==3
	  drop _m

	  replace stud=. if subspec~=1
	  replace pmas=. if subspec~=1
	  replace pzex=. if subspec~=1
	  replace poex=. if subspec~=1
	  replace ptex=. if subspec~=1
	  replace ptfex=. if subspec~=1
	  replace pfnex=. if subspec~=1
	  replace ptwex=. if subspec~=1
	  replace pthex=. if subspec~=1
	  replace exper=. if subspec~=1
	  replace numtea=. if subspec~=1


	  di "rename variables"
          rename pmas pmas`grloop'`yrloop'
          rename pzex pzex`grloop'`yrloop'
          rename poex poex`grloop'`yrloop'
          rename ptex ptex`grloop'`yrloop'
          rename ptfex ptfex`grloop'`yrloop'
          rename pfnex pfnex`grloop'`yrloop'
          rename ptwex ptwex`grloop'`yrloop'
          rename pthex pthex`grloop'`yrloop'
          rename campus camp`grloop'`yrloop'
          rename exper exper`grloop'`yrloop'
          rename stud stud`grloop'`yrloop'
          rename numtea numt`grloop'`yrloop'

          #delimit ;
          keep camp`grloop'`yrloop' exper`grloop'`yrloop' stud`grloop'`yrloop'
          pmas`grloop'`yrloop' pzex`grloop'`yrloop' numt`grloop'`yrloop'
          poex`grloop'`yrloop' ptex`grloop'`yrloop' ptfex`grloop'`yrloop'
          pfnex`grloop'`yrloop'  ptwex`grloop'`yrloop' pthex`grloop'`yrloop' ;
          #delimit cr

          sort camp`grloop'`yrloop'
	  quietly by camp`grloop'`yrloop': assert _N==1

          save ${rivkin_home}simba_e/texdata/Texas/teacher/mtht`grloop'`yrloop',replace
          clear

          local yrloop = `yrloop' + 1
     }

     local grloop = `grloop' + 1
}


di "create data sets english teachers for grades 4 - 7"
local grloop = 4
while `grloop'<=7 {

     local yrloop=93
     while `yrloop' <=96 {

          di "using data for `grloop'th grade in `yrloop'"
          use ${rivkin_home}simba_e/texdata/Texas/teacher/tbycgs
          keep if grade==`grloop' & subject==12 & numtea>0 & numtea~=. & year==`yrloop'


	  di "merge with subject specialty data, set nonspecialty schools to missing"
	  sort camp grade year
	  merge camp grade year using ${rivkin_home}simba_e/texdata/Texas/teacher/subspeci
	  tab _m
	  keep if _m==3
	  drop _m

	  replace stud=. if subspec~=1
	  replace pmas=. if subspec~=1
	  replace pzex=. if subspec~=1
	  replace poex=. if subspec~=1
	  replace ptex=. if subspec~=1
	  replace ptfex=. if subspec~=1
	  replace pfnex=. if subspec~=1
	  replace ptwex=. if subspec~=1
	  replace pthex=. if subspec~=1
	  replace exper=. if subspec~=1
	  replace numtea=. if subspec~=1


	  di "rename variables"
          rename pmas pmas`grloop'`yrloop'
          rename pzex pzex`grloop'`yrloop'
          rename poex poex`grloop'`yrloop'
          rename ptex ptex`grloop'`yrloop'
          rename ptfex ptfex`grloop'`yrloop'
          rename pfnex pfnex`grloop'`yrloop'
          rename ptwex ptwex`grloop'`yrloop'
          rename pthex pthex`grloop'`yrloop'
          rename campus camp`grloop'`yrloop'
          rename exper exper`grloop'`yrloop'
          rename stud stud`grloop'`yrloop'
          rename numtea numt`grloop'`yrloop'

          #delimit ;
          keep camp`grloop'`yrloop' exper`grloop'`yrloop' stud`grloop'`yrloop'
          pmas`grloop'`yrloop' pzex`grloop'`yrloop' numt`grloop'`yrloop'
          poex`grloop'`yrloop' ptex`grloop'`yrloop' ptfex`grloop'`yrloop'
          pfnex`grloop'`yrloop'  ptwex`grloop'`yrloop' pthex`grloop'`yrloop';
          #delimit cr

          sort camp`grloop'`yrloop'
	  quietly by camp`grloop'`yrloop': assert _N==1

          save ${rivkin_home}simba_e/texdata/Texas/teacher/engt`grloop'`yrloop',replace
          clear

          local yrloop = `yrloop' + 1
     }

     local grloop = `grloop' + 1
}

di "create data sets for math teachers for grades 6 and 7 in 1997 and 1998"
local grloop = 6
while `grloop'<=7 {

     local yrloop=97
     while `yrloop' <=98 {

          di "using data for `grloop'th grade in `yrloop'"
          use ${rivkin_home}simba_e/texdata/Texas/teacher/tbycgs
          keep if grade==`grloop' & subject==28 & numtea>0 & numtea~=. & year==`yrloop'

	  di "merge with subject specialty data, set nonspecialty schools to missing"
	  sort camp grade year
	  merge camp grade year using ${rivkin_home}simba_e/texdata/Texas/teacher/subspeci
	  tab _m
	  keep if _m==3
	  drop _m

	  replace stud=. if subspec~=1
	  replace pmas=. if subspec~=1
	  replace pzex=. if subspec~=1
	  replace poex=. if subspec~=1
	  replace ptex=. if subspec~=1
	  replace ptfex=. if subspec~=1
	  replace pfnex=. if subspec~=1
	  replace ptwex=. if subspec~=1
	  replace pthex=. if subspec~=1
	  replace exper=. if subspec~=1
	  replace numtea=. if subspec~=1


	  di "rename variables"
          rename pmas pmas`grloop'`yrloop'
          rename pzex pzex`grloop'`yrloop'
          rename poex poex`grloop'`yrloop'
          rename ptex ptex`grloop'`yrloop'
          rename ptfex ptfex`grloop'`yrloop'
          rename pfnex pfnex`grloop'`yrloop'
          rename ptwex ptwex`grloop'`yrloop'
          rename pthex pthex`grloop'`yrloop'
          rename campus camp`grloop'`yrloop'
          rename exper exper`grloop'`yrloop'
          rename stud stud`grloop'`yrloop'
          rename numtea numt`grloop'`yrloop'

          #delimit ;
          keep camp`grloop'`yrloop' exper`grloop'`yrloop' stud`grloop'`yrloop'
          pmas`grloop'`yrloop' pzex`grloop'`yrloop' numt`grloop'`yrloop'
          poex`grloop'`yrloop' ptex`grloop'`yrloop' ptfex`grloop'`yrloop'
          pfnex`grloop'`yrloop'  ptwex`grloop'`yrloop' pthex`grloop'`yrloop' ;
          #delimit cr

          sort camp`grloop'`yrloop'
	  quietly by camp`grloop'`yrloop': assert _N==1

          save ${rivkin_home}simba_e/texdata/Texas/teacher/mtht`grloop'`yrloop',replace
          clear

          local yrloop = `yrloop' + 1
     }

     local grloop = `grloop' + 1
}


di "create data sets english teachers for grades 6 and 7 in 1997 and 1998 "
local grloop = 6
while `grloop'<=7 {

     local yrloop=97
     while `yrloop' <=98 {

          di "using data for `grloop'th grade in `yrloop'"
          use ${rivkin_home}simba_e/texdata/Texas/teacher/tbycgs
          keep if grade==`grloop' & subject==12 & numtea>0 & numtea~=. & year==`yrloop'


	  di "merge with subject specialty data, set nonspecialty schools to missing"
	  sort camp grade year
	  merge camp grade year using ${rivkin_home}simba_e/texdata/Texas/teacher/subspeci
	  tab _m
	  keep if _m==3
	  drop _m

	  replace stud=. if subspec~=1
	  replace pmas=. if subspec~=1
	  replace pzex=. if subspec~=1
	  replace poex=. if subspec~=1
	  replace ptex=. if subspec~=1
	  replace ptfex=. if subspec~=1
	  replace pfnex=. if subspec~=1
	  replace ptwex=. if subspec~=1
	  replace pthex=. if subspec~=1
	  replace exper=. if subspec~=1
	  replace numtea=. if subspec~=1


	  di "rename variables"
          rename pmas pmas`grloop'`yrloop'
          rename pzex pzex`grloop'`yrloop'
          rename poex poex`grloop'`yrloop'
          rename ptex ptex`grloop'`yrloop'
          rename ptfex ptfex`grloop'`yrloop'
          rename pfnex pfnex`grloop'`yrloop'
          rename ptwex ptwex`grloop'`yrloop'
          rename pthex pthex`grloop'`yrloop'
          rename campus camp`grloop'`yrloop'
          rename exper exper`grloop'`yrloop'
          rename stud stud`grloop'`yrloop'
          rename numtea numt`grloop'`yrloop'

          #delimit ;
          keep camp`grloop'`yrloop' exper`grloop'`yrloop' stud`grloop'`yrloop'
          pmas`grloop'`yrloop' pzex`grloop'`yrloop' numt`grloop'`yrloop'
          poex`grloop'`yrloop' ptex`grloop'`yrloop' ptfex`grloop'`yrloop'
          pfnex`grloop'`yrloop'  ptwex`grloop'`yrloop' pthex`grloop'`yrloop';
          #delimit cr

          sort camp`grloop'`yrloop'
	  quietly by camp`grloop'`yrloop': assert _N==1

          save ${rivkin_home}simba_e/texdata/Texas/teacher/engt`grloop'`yrloop',replace
          clear

          local yrloop = `yrloop' + 1
     }

     local grloop = `grloop' + 1
}

end
