 /**this file renames variables for each year using taas data for 1993-1997 (the 4th grade cohort
in 1993).  It then merges data together, separating complete and incomplete data sets.**/

cap log close
log using e:/tchrqual/tqualdat.log,replace

set memory 750m
set more off

di "create tempfiles"
tempfile tempq tempdat tempdfr tempexp tempex2

tempfile dat1954 dat1955 dat1956 dat1957 dat1958 dat195 tea195
tempfile dat1964 dat1965 dat1966 dat1967 dat1968 dat196 tea196
tempfile dat1974 dat1975 dat1976 dat1977 dat1978 dat197 tea197
tempfile dat1984 dat1985 dat1986 dat1987 dat1988 dat198 tea198
tempfile dat1994 dat1995 dat1996 dat1997 dat1998 dat199 tea199
tempfile dat2004 dat2005 dat2006 dat2007 dat2008 dat200 tea200
tempfile dat2014 dat2015 dat2016 dat2017 dat2018 dat201 tea201
/*
use tcoef202 camp advdeg tminusc202 curcbla nxtcbla curceco nxtceco curclep nxtclep cursal nxtsal PID year using dataforregs_less1pct
sort PID year
quietly by PID year: keep if _n==_N
sort PID year
save `tempdfr'
*/

local yrloop=196
while `yrloop' <=201 {

	di "assign math teachers to students"

	use f:\hisd\assign_math_tchr_`yrloop'_1
	sort PID altpid campus
	save f:\hisd\assign_math_tchr_`yrloop'_2,replace

	use f:\hisd\combexp`yrloop'_less1pct
	sort PID altpid campus
	merge PID altpid campus using f:\hisd\assign_math_tchr_`yrloop'_2
	tab _m
	keep if _m==3
	drop _m

	gen int year=`yrloop'
	sort altpid campus year
	quietly by altpid campus year: assert _N==_n
	save `tea`yrloop''

	local yrloop = `yrloop'+1
	}

local yrloop=196
while `yrloop' <=201 {

	di "process student data and match with teachers"
	local grloop=4
	while `grloop' <= 8 {

		use camp`yrloop'`grloop' altpid sex`yrloop'`grloop' eth`yrloop'`grloop' econ`yrloop'`grloop' /*
		*/ lep`yrloop'`grloop' spec`yrloop'`grloop' zred`yrloop'`grloop' zmth`yrloop'`grloop' /*
		*/ zmgain`yrloop'`grloop' zrgain`yrloop'`grloop' using f:\hisd\hisdgain`yrloop'`grloop'_less1pct


		drop if zmth`yrloop'`grloop'==.

		di "removing year and grade suffix from variable names"
		foreach x in camp sex eth econ lep spec zred zmth zrgain zmgain {

			rename `x'`yrloop'`grloop' `x'
			}

		gen int year = `yrloop'
		gen byte grade = `grloop'

		save `dat`yrloop'`grloop''
		d
		sum

		local grloop = `grloop' + 1

		}

	di "appending data sets"
	local aploop=7
	while `aploop'>=4 {

		append using `dat`yrloop'`aploop''

		local aploop = `aploop' - 1

		}


	di "merge with teacher data"

	di "drop observations that are not unique altpids in a year"
	egen numc=count(camp),by(altpid)
	tab numc
	keep if numc==1

	drop camp
	sort altpid
	merge altpid using `tea`yrloop''
	tab _m
	keep if _m==3
	drop _m

	di "drop year suffixes from teacher variables"
	foreach x in expcat exper tmove {
		rename `x'`yrloop' `x'
		}

	d
	sum

	sort altpid year
	save `dat`yrloop''
	d
	sum

	local yrloop = `yrloop' + 1

	}

di "append data sets"

local aploop = 200
while `aploop'>=196 {

	append using `dat`aploop''
	d
	sum

	local aploop = `aploop' - 1

	}

sort PID year
save `tempdat'


gen premath= zmth-zmgain
gen preread= zred-zrgain


egen maxsc=max(premath),by(grade year)
egen minsc=min(premath),by(grade year)

di "generate groups"

gen range=maxsc-minsc
gen catsz5=range/5
gen catsz10=range/10


gen grp5m=.

local grnum = 1
while `grnum'<=5 {

	gen max`grnum' = minsc+(`grnum'*catsz5)
	sum max`grnum'
	replace grp5m=`grnum' if grp5m==. & premath>=minsc & premath<=max`grnum'
	tab grp5m

	local grnum = `grnum' + 1
	}

drop max1 max2 max3 max4 max5
gen grp10m=.

local grnum = 1
while `grnum'<=10 {

	gen max`grnum' = minsc+(`grnum'*catsz10)
	replace grp10m=`grnum' if grp10m==. & premath>=minsc & premath<=max`grnum'
	replace grp10m=. if premath==.

	local grnum = `grnum' + 1
	}

sort grade grp5m
by grade grp5m: sum premath

sort grade grp10m
by grade grp10m: sum premath

di "compute average gains for each group"
egen avegaig5=mean(zmgain),by(grp5m year grade)
egen avegaig10=mean(zmgain),by(grp10m year grade)
egen stgaig5=sd(zmgain),by(grp5m year grade)
egen stgaig10=sd(zmgain),by(grp10m year grade)


sort grp10m
by grp10m: sum avegaig*

di "compute teacher average gains for each group"
egen tgaig5=mean(zmgain),by(PID grp5m year)
egen tgaig10=mean(zmgain),by(PID grp10m year)

di "compute teacher average standardized deviations from average gains for each group"
gen dtgaig5=(tgaig5-avegaig5)/stgaig5
gen dtgaig10=(tgaig10-avegaig10)/stgaig10
replace dtgaig5=. if zmgain==.
replace dtgaig10=. if zmgain==.

di "generate student level observations of adjusted gains"
gen sdtgaig10=(zmgain-avegaig10)/stgaig10 if zmgain~=.

di "generate deviations and cell counts with group suffixes"

local grp5=1
while `grp5' <= 5 {

	gen dga5`grp5'=dtgaig5 if grp5m==`grp5'
	egen cntga5`grp5'=count(dtgaig5),by(PID year grp5m)
	replace cntga5`grp5' = . if grp5m~=`grp5'
	
	local grp5 = `grp5' + 1

	}


local grp10=1
while `grp10' <= 10 {

	gen dga10`grp10'=dtgaig10 if grp10m==`grp10'
	egen cntga10`grp10'=count(dtgaig10),by(PID year grp10m)
	replace cntga10`grp10' = . if grp10m~=`grp10'

	local grp10 = `grp10' + 1

	}


di "compute overall variance"

egen numstud=count(zmgain),by(PID campus year)
sum zmgain sdtgaig10 if numstud>=10 & numstud~=.,detail
drop numstud


di as result "Save Dan's file"
sort PID altpid
compress
save f:\hisd\dtagig10_for_fe_regs,replace

sort year grade
by year grade: sum maxsc minsc range cat* dtgaig10 zmgain


di "collapse data by PID, campus and year"
collapse tmove expcat exper avmgain=zmgain avmath=zmth dga51-dga55 dga101-dga1010 /*
*/ cnt51=cntga51 cnt52=cntga52 cnt53=cntga53 cnt54=cntga54 cnt55=cntga55 /*
*/ cnt101=cntga101 cnt102=cntga102 cnt103=cntga103 cnt104=cntga104 cnt105=cntga105 /*
*/ cnt106=cntga106 cnt107=cntga107 cnt108=cntga108 cnt109=cntga109 cnt1010=cntga1010 (count) numstud=zmgain,by(PID campus year)

drop cntga5*
d
sum
/*
sort PID year
merge PID year using `tempdfr'
tab _m
drop _m
*/
sort PID year
quietly by PID year: assert _n==_N

di "compute fixed weight average"
gen tot=0
local num = 101
while `num'<=109 {

	replace dga`num'=0 if dga`num'==.
	replace cnt`num'=0 if cnt`num'==.

	sum

	egen tot`num'=sum(cnt`num')	
	replace tot=tot+tot`num'

	local num = `num'+1
	}

replace dga1010=0 if dga1010==.
replace cnt1010=0 if cnt1010==.

egen tot1010=sum(cnt1010)	
replace tot=tot+tot1010

sum

rename tot totsamp

gen devscore=0
gen dev14=0
gen dev57=0
gen dev810=0

di "compute fixed weights of cell counts"
local num = 101
while `num'<=109 {

	gen wgt`num'=tot`num'/totsamp
	replace devscore=devscore+(wgt`num'*dga`num')
	replace dev14=dev14+(wgt`num'*dga`num') if `num'>=101 & `num'<=104
	replace dev57=dev57+(wgt`num'*dga`num') if `num'>=105 & `num'<=107
	replace dev810=dev810+(wgt`num'*dga`num') if `num'>=108 & `num'<=109

	local num = `num'+1
	}

gen wgt1010=tot1010/totsamp
replace devscore=devscore+(wgt1010*dga1010)
replace dev810 = dev810+(wgt1010*dga1010)
rename devscore dtgaig10



sum

save f:\hisd\tqualdat,replace
d
sum

cor dga101-dga1010


