/**this file creates a data file that reports the continuity of teachers by campus, year and grade. It
computes the percentage of teachers who remain in the same campus/grade two years in
a row, for all subjects and for math and english separately**/

capture program drop turnov3
program define turnov3

tempfile tempone tempdat temp5 temp6 temp7

set more off
cap log close
log using ${rivkin_home}simba_e/Texas/quality/RESULTS/turnov3.log,replace

di "create indicators of subject specialty campus grades"
use ${rivkin_home}simba_e/texdata/Texas/teacher/subspeci
rename subspec subspe

di "reshape data"
reshape groups year 94 95 96 97 98
reshape vars subsp 
reshape cons campus grade
reshape query  
reshape wide
sort campus grade
save `tempone'
d

di "using masttea2"
use ${rivkin_home}simba_e/texdata/Texas/teacher/masttea2
sort campus grade
merge campus grade using `tempone'
tab _m
drop _m

local yrloop=93
while `yrloop'<=98 {

     gen teach`yrloop'=0
     replace teach`yrloop'= 1 if (stud`yrloop'>=5 & stud`yrloop' <=99)
     egen tany`yrloop'=max(teach`yrloop'),by(PID campus)
     egen tsw`yrloop'=max(teach`yrloop'),by(PID)

     tab tany`yrloop' tsw`yrloop'

     di "create indicator for whether taught in any subject during year`yrloop'"
     di "create indicator for whether taught in any subject during year`yrloop' and had zero year experience in first"
     gen ntea`yrloop'=0
     replace ntea`yrloop'=1 if stud`yrloop'>=5 & stud`yrloop'<=99 & exper`yrloop'==0
     egen ntany`yrloop'=max(ntea`yrloop'),by(PID campus grade)

     di "create indicator for taught math, english or general"
     gen math`yrloop'=teach`yrloop'==1 & subject==28
     egen tmath`yrloop'=max(math`yrloop'),by(PID campus grade)

     gen eng`yrloop'=teach`yrloop'==1 & subject==12
     egen teng`yrloop'=max(eng`yrloop'),by(PID campus grade)

     gen gen`yrloop'=teach`yrloop'==1 & subject==16
     egen tgen`yrloop'=max(gen`yrloop'),by(PID campus grade)

     gen both`yrloop'=teng`yrloop'==1 & tmath`yrloop'==1
     replace both`yrloop'=. if teng`yrloop'==0 & tmath`yrloop'==0 & tany`yrloop'==0

     local yrloop = `yrloop' + 1
}

di "create variable indicating teachers who taught in subjects two consecutive years"
local yrloop=94
while `yrloop' <=98 {

     local prev = `yrloop' - 1

     di "teacher two years in a row"

     di "math teacher two years in a row"
     gen mtot`yrloop'`prev'=.
     replace mtot`yrloop'`prev'=(teach`yrloop' + teach`prev')/2 if subject==28
     replace mtot`yrloop'`prev'=. if mtot`yrloop'`prev'==0

     gen msam`yrloop'`prev'=.
     replace msam`yrloop'`prev'=min(teach`yrloop', teach`prev') if subject==28
     replace msam`yrloop'`prev'=. if mtot`yrloop'`prev'==0

     di "new math teacher two years in a row in same campus"
     gen nmsa`yrloop'`prev'=.
     replace nmsa`yrloop'`prev'=ntea`prev'==1 & tany`yrloop'==1 if subject==28
     replace nmsa`yrloop'`prev'=. if ntea`prev'~=1 | subject~=28

     di "new math teacher two years in a row"
     gen nmre`yrloop'`prev'=.
     replace nmre`yrloop'`prev'=ntea`prev'==1 & tsw`yrloop'==1 if subject==28
     replace nmre`yrloop'`prev'=. if ntea`prev'~=1 | subject~=28

     tab nmsa`yrloop' nmre`yrloop'

     di "math or general teacher two years in a row"
     gen atot`yrloop'`prev'=.
     replace atot`yrloop'`prev'=(teach`yrloop' + teach`prev')/2 if subject==28 | subject==16
     replace atot`yrloop'`prev'=. if atot`yrloop'`prev'==0

     gen asam`yrloop'`prev'=.
     replace asam`yrloop'`prev'=min(teach`yrloop', teach`prev') if subject==28 | subject==16
     replace asam`yrloop'`prev'=. if atot`yrloop'`prev'==0

     di "new all teacher two years in a row in same campus"
     gen nasa`yrloop'`prev'=.
     replace nasa`yrloop'`prev'=ntea`prev'==1 & (tany`yrloop'==1 | ntea`yrloop'==1) if subject==28 | subject==16
     replace nasa`yrloop'`prev'=. if ntea`prev'~=1 | (subject~=28 & subject~=16)

     di "new all teacher two years in a row"
     gen nare`yrloop'`prev'=.
     replace nare`yrloop'`prev'=ntea`prev'==1 & tsw`yrloop'==1 if subject==28 | subject==16
     replace nare`yrloop'`prev'=. if ntea`prev'~=1 | (subject~=28 & subject~=16)

     tab nasa`yrloop' nare`yrloop'

     local yrloop=`yrloop' + 1
}


save ${rivkin_home}simba_e/texdata/Texas/teacher/check,replace

di "collapsing data by PID, campus and grade to take out duplicates for calcs of all teachers"

#delimit ;
collapse (max) nmsa9594 nmsa9695 nmsa9796 nmsa9897 nasa9594 nasa9695 nasa9796 nasa9897 
nmre9594 nmre9695 nmre9796 nmre9897 nare9594 nare9695 nare9796 nare9897
subsp94 subsp95 subsp96 subsp97 subsp98, by(PID campus grade);
sum;

di "collapsing data by campus and grade";

collapse (mean) nmsa9594 nmsa9695 nmsa9796 nmsa9897 nasa9594 nasa9695 nasa9796 nasa9897 
nmre9594 nmre9695 nmre9796 nmre9897 nare9594 nare9695 nare9796 nare9897
subsp94 subsp95 subsp96 subsp97 subsp98, by(campus grade);
sum;

#delimit cr

tab nmsa9594 nmre9594
tab nasa9594 nare9594

di "creating indicators for observations to drop"

gen byte drop797=0 if grade==7
gen byte drop796=0 if grade==7

gen byte drop697=0 if grade==6
gen byte drop695=0 if grade==6
gen byte drop696=0 if grade==6

gen byte drop594=0 if grade==5
gen byte drop595=0 if grade==5
gen byte drop596=0 if grade==5

gen byte drop495=0 if grade==4

gen byte dropa797=0 if grade==7
gen byte dropa796=0 if grade==7

gen byte dropa697=0 if grade==6
gen byte dropa695=0 if grade==6
gen byte dropa696=0 if grade==6

gen byte dropa594=0 if grade==5
gen byte dropa595=0 if grade==5
gen byte dropa596=0 if grade==5

gen byte dropa495=0 if grade==4

replace drop594=1 if ((nmsa9594~=1 & nmsa9594~=. & subsp94==1 & subsp95==1) | (nasa9594~=1 & nasa9594~=. & (subsp94~=1 | subsp95~=1))) & grade==5
replace drop595=1 if ((nmsa9695~=1 & nmsa9695~=. & subsp95==1 & subsp96==1) | (nasa9695~=1 & nasa9695~=. & (subsp95~=1 | subsp96~=1))) & grade==5
replace drop596=1 if ((nmsa9796~=1 & nmsa9796~=. & subsp96==1 & subsp97==1) | (nasa9796~=1 & nasa9796~=. & (subsp96~=1 | subsp97~=1))) & grade==5

replace drop495=1 if ((nmsa9695~=1 & nmsa9695~=. & subsp95==1 & subsp96==1) | (nasa9695~=1 & nasa9695~=. & (subsp95~=1 | subsp96~=1))) & grade==4

replace drop695=1 if ((nmsa9695~=1 & nmsa9695~=. & subsp95==1 & subsp96==1) | (nasa9695~=1 & nasa9695~=. & (subsp95~=1 | subsp96~=1))) & grade==6
replace drop696=1 if ((nmsa9796~=1 & nmsa9796~=. & subsp96==1 & subsp97==1) | (nasa9796~=1 & nasa9796~=. & (subsp96~=1 | subsp97~=1))) & grade==6
replace drop697=1 if ((nmsa9897~=1 & nmsa9897~=. & subsp97==1 & subsp98==1) | (nasa9897~=1 & nasa9897~=. & (subsp97~=1 | subsp98~=1))) & grade==6

replace drop796=1 if ((nmsa9796~=1 & nmsa9796~=. & subsp96==1 & subsp97==1) | (nasa9796~=1 & nasa9796~=. & (subsp96~=1 | subsp97~=1))) & grade==7
replace drop797=1 if ((nmsa9897~=1 & nmsa9897~=. & subsp97==1 & subsp98==1) | (nasa9897~=1 & nasa9897~=. & (subsp97~=1 | subsp98~=1))) & grade==7

replace dropa594=1 if ((nmre9594~=1 & nmre9594~=. & subsp94==1 & subsp95==1) | (nare9594~=1 & nare9594~=. & (subsp94~=1 | subsp95~=1))) & grade==5
replace dropa595=1 if ((nmre9695~=1 & nmre9695~=. & subsp95==1 & subsp96==1) | (nare9695~=1 & nare9695~=. & (subsp95~=1 | subsp96~=1))) & grade==5
replace dropa596=1 if ((nmre9796~=1 & nmre9796~=. & subsp96==1 & subsp97==1) | (nare9796~=1 & nare9796~=. & (subsp96~=1 | subsp97~=1))) & grade==5

replace dropa495=1 if ((nmre9695~=1 & nmre9695~=. & subsp95==1 & subsp96==1) | (nare9695~=1 & nare9695~=. & (subsp95~=1 | subsp96~=1))) & grade==4

replace dropa695=1 if ((nmre9695~=1 & nmre9695~=. & subsp95==1 & subsp96==1) | (nare9695~=1 & nare9695~=. & (subsp95~=1 | subsp96~=1))) & grade==6
replace dropa696=1 if ((nmre9796~=1 & nmre9796~=. & subsp96==1 & subsp97==1) | (nare9796~=1 & nare9796~=. & (subsp96~=1 | subsp97~=1))) & grade==6
replace dropa697=1 if ((nmre9897~=1 & nmre9897~=. & subsp97==1 & subsp98==1) | (nare9897~=1 & nare9897~=. & (subsp97~=1 | subsp98~=1))) & grade==6

replace dropa796=1 if ((nmre9796~=1 & nmre9796~=. & subsp96==1 & subsp97==1) | (nare9796~=1 & nare9796~=. & (subsp96~=1 | subsp97~=1))) & grade==7
replace dropa797=1 if ((nmre9897~=1 & nmre9897~=. & subsp97==1 & subsp98==1) | (nare9897~=1 & nare9897~=. & (subsp97~=1 | subsp98~=1))) & grade==7

rename campus camp


save `tempdat'

keep if grade==5

di "reshaping data set"
reshape groups year 594 595 596
reshape vars drop dropa
reshape cons camp
reshape long

save `temp5'

use `tempdat'

keep if grade==6

di "reshaping data set"
reshape groups year 695 696 697
reshape vars drop dropa
reshape cons camp
reshape long

save `temp6'

use `tempdat'

keep if grade==7

di "reshaping data set"
reshape groups year 796 797
reshape vars drop dropa
reshape cons camp
reshape long

save `temp7'

use `tempdat'

keep if grade==4

di "reshaping data set"
reshape groups year 495
reshape vars drop dropa
reshape cons camp
reshape long

append using `temp5'
append using `temp6'
append using `temp7'

sort camp year
save ${rivkin_home}simba_e/texdata/Texas/teacher/turnov3,replace

tab drop dropa

end
