/**this file creates a data file that reports the continuity of teachers by campus, year and grade. It
computes the percentage of teachers who remain in the same campus/grade two years in
a row, for all subjects and for math and english separately**/

capture program drop turnov2
program define turnov2

tempfile tempone

set more off
cap log close
log using ${rivkin_home}simba_e/Texas/quality/RESULTS/turnover.log,replace

di "create indicators of subject specialty campus grades"
use ${rivkin_home}simba_e/texdata/Texas/teacher/subspeci
rename subspec subspe

di "reshape data"
reshape groups year 93 94 95 96 97 98
reshape vars subsp 
reshape cons campus grade
reshape query  
reshape wide
sort campus grade
save `tempone'
d

di "using masttea2"
use ${rivkin_home}simba_e/texdata/Texas/teacher/masttea2
sort campus grade
merge campus grade using `tempone'
tab _m
drop _m

local yrloop=93
while `yrloop'<=98 {

     di "create indicator for whether taught in any subject during year`yrloop'"
     gen teach`yrloop'=0
     replace teach`yrloop'= 1 if (stud`yrloop'>=5 & stud`yrloop' <=99)
     egen tany`yrloop'=max(teach`yrloop'),by(PID campus grade)

     di "create indicator for taught math, english or general"
     gen math`yrloop'=teach`yrloop'==1 & subject==28
     egen tmath`yrloop'=max(math`yrloop'),by(PID campus grade)

     gen eng`yrloop'=teach`yrloop'==1 & subject==12
     egen teng`yrloop'=max(eng`yrloop'),by(PID campus grade)

     gen gen`yrloop'=teach`yrloop'==1 & subject==16
     egen tgen`yrloop'=max(gen`yrloop'),by(PID campus grade)

	di "create indicator for teaching general or math"
	gen mgteach`yrloop'=teach`yrloop'==1 & (subject==28 | subject==16)
      egen tmgen`yrloop'=max(mgteach`yrloop'),by(PID campus grade)

	di "create indicator for teaching general or english"
	gen egteach`yrloop'=teach`yrloop'==1 & (subject==12 | subject==16)
      egen tegen`yrloop'=max(egteach`yrloop'),by(PID campus grade)

     gen both`yrloop'=(teng`yrloop'==1 & tmgen`yrloop'==1) | (tmath`yrloop'==1 & tegen`yrloop'==1) | tgen`yrloop'==1
     replace both`yrloop'=. if tany`yrloop'==0

	di "generate indicator for zero years experience"
	gen byte mzexp`yrloop'=exper`yrloop'==0 & tmgen`yrloop'==1
	replace mzexp`yrloop'=. if tmgen`yrloop'~=1
	egen mzexdum`yrloop'=max(mzexp`yrloop'),by(PID campus grade)

	gen byte ezexp`yrloop'=exper`yrloop'==0 & tegen`yrloop'==1
	replace ezexp`yrloop'=. if tegen`yrloop'~=1
	egen ezexdum`yrloop'=max(ezexp`yrloop'),by(PID campus grade)

	di "generate indicator for one year experience"
	gen byte moexp`yrloop'=exper`yrloop'==1 & tmgen`yrloop'==1
	replace moexp`yrloop'=. if tmgen`yrloop'~=1
	egen moexdum`yrloop'=max(moexp`yrloop'),by(PID campus grade)

	gen byte eoexp`yrloop'=exper`yrloop'==1 & tegen`yrloop'==1
	replace eoexp`yrloop'=. if tegen`yrloop'~=1
	egen eoexdum`yrloop'=max(eoexp`yrloop'),by(PID campus grade)

	di "create indicators for teachers in subject in year"
	foreach x in tmath teng tgen tegen tmgen {
		egen c`x'`yrloop'=max(`x'`yrloop'),by(campus grade)
		}

     local yrloop = `yrloop' + 1
}

di "keep one observation per PID, campus and grade"
sort PID campus grade
quietly by PID campus grade: keep if _N==_n

di "create variable indicating teachers who taught in subjects two consecutive years"
local yrloop=94
while `yrloop' <=98 {

     local prev = `yrloop' - 1

     di "teacher two years in a row"

     gen gtot`yrloop'`prev'=.
     replace gtot`yrloop'`prev'=(tgen`yrloop' + tgen`prev')/2
     replace gtot`yrloop'`prev'=. if gtot`yrloop'`prev'==0 | ctgen`yrloop'~=1 | ctgen`prev'~=1

     gen gsam`yrloop'`prev'=.
     replace gsam`yrloop'`prev'=min(tgen`yrloop',tgen`prev')
     replace gsam`yrloop'`prev'=. if gtot`yrloop'`prev'==. | ctgen`yrloop'~=1 | ctgen`prev'~=1

     di "math teacher two years in a row"
     gen mtot`yrloop'`prev'=.
     replace mtot`yrloop'`prev'=(tmath`yrloop' + tmath`prev')/2
     replace mtot`yrloop'`prev'=. if mtot`yrloop'`prev'==0 | ctmath`yrloop'~=1 | ctmath`prev'~=1

     gen msam`yrloop'`prev'=.
     replace msam`yrloop'`prev'=min(tmath`yrloop', tmath`prev')
     replace msam`yrloop'`prev'=. if mtot`yrloop'`prev'==0 | ctmath`yrloop'~=1 | ctmath`prev'~=1

     di "english teacher two years in a row"
     gen etot`yrloop'`prev'=.
     replace etot`yrloop'`prev'=(teng`yrloop' + teng`prev')/2
     replace etot`yrloop'`prev'=. if etot`yrloop'`prev'==0 | cteng`yrloop'~=1 | cteng`prev'~=1

     gen esam`yrloop'`prev'=.
     replace esam`yrloop'`prev'=min(teng`yrloop', teng`prev')
     replace esam`yrloop'`prev'=. if etot`yrloop'`prev'==0 | cteng`yrloop'~=1 | cteng`prev'~=1

     di "math or general teacher two years in a row"
     gen mgtot`yrloop'`prev'=.
     replace mgtot`yrloop'`prev'=(tmgen`yrloop' + tmgen`prev')/2
     replace mgtot`yrloop'`prev'=. if mgtot`yrloop'`prev'==0 | ctmgen`yrloop'~=1 | ctmgen`prev'~=1

     gen mgsam`yrloop'`prev'=.
     replace mgsam`yrloop'`prev'=min(tmgen`yrloop', tmgen`prev')
     replace mgsam`yrloop'`prev'=. if mgtot`yrloop'`prev'==0 | ctmgen`yrloop'~=1 | ctmgen`prev'~=1

     di "english or general teacher two years in a row"
     gen egtot`yrloop'`prev'=.
     replace egtot`yrloop'`prev'=(tegen`yrloop' + tegen`prev')/2
     replace egtot`yrloop'`prev'=. if egtot`yrloop'`prev'==0 | ctegen`yrloop'~=1 | ctegen`prev'~=1

     gen egsam`yrloop'`prev'=.
     replace egsam`yrloop'`prev'=min(tegen`yrloop', tegen`prev')
     replace egsam`yrloop'`prev'=. if egtot`yrloop'`prev'==0 | ctegen`yrloop'~=1 | ctegen`prev'~=1

	di "generate variable indicating going from 0 to 1 yr experience"
	gen gaix`yrloop'`prev'=(mzexdum`yrloop'~=1 & mzexdum`prev'==1)

	di "generate subject specific indicators for experience gain"
	gen mggx`yrloop'`prev'=mzexdum`yrloop'~=1 & mzexdum`prev'==1 & mgsam`yrloop'`prev'==1
	replace mggx`yrloop'`prev'=. if tmgen`yrloop'~=1 & tmgen`prev'~=1

	gen eggx`yrloop'`prev'=ezexdum`yrloop'~=1 & ezexdum`prev'==1 & egsam`yrloop'`prev'==1
	replace eggx`yrloop'`prev'=. if tegen`yrloop'~=1 & tegen`prev'~=1

      local yrloop=`yrloop' + 1
}

save ${rivkin_home}simba_e/texdata/Texas/teacher/check,replace
sum
sort grade
by grade: sum both* if grade==5 | grade==6 | grade==7,detail

#delimit ;
di "collapsing data by campus and grade";

collapse (sum)    gtot9493 gtot9594 gtot9695 gtot9796 gtot9897
                  mtot9493 mtot9594 mtot9695 mtot9796 mtot9897 
			etot9493 etot9594 etot9695 etot9796 etot9897
                  mgtot9493 mgtot9594 mgtot9695 mgtot9796 mgtot9897
                  egtot9493 egtot9594 egtot9695 egtot9796 egtot9897
                  gsam9493 gsam9594 gsam9695 gsam9796 gsam9897 
			mgsam9493 mgsam9594 mgsam9695 mgsam9796 mgsam9897
			egsam9493 egsam9594 egsam9695 egsam9796 egsam9897
                  msam9493 msam9594 msam9695 msam9796 msam9897 
			esam9493 esam9594 esam9695 esam9796 esam9897
			mggx9493 mggx9594 mggx9695 mggx9796 mggx9897
			eggx9493 eggx9594 eggx9695 eggx9796 eggx9897

                  (mean) subsp93 subsp94 subsp95 subsp96 subsp97 subsp98 
			mzexdum93 mzexdum94 mzexdum95 mzexdum96 mzexdum97 mzexdum98
			ezexdum93 ezexdum94 ezexdum95 ezexdum96 ezexdum97 ezexdum98
			moexdum93 moexdum94 moexdum95 moexdum96 moexdum97 moexdum98
			eoexdum93 eoexdum94 eoexdum95 eoexdum96 eoexdum97 eoexdum98
			(max) 
			both93 both94 both95 both96 both97 both98,
                  by(campus grade) ;
sum;

#delimit cr

tab both94 both95
tab both95 both96
tab both96 both97
tab both97 both98

local yr=93
while `yr'<=97 {

	local nyr=`yr'+1

	di "generate indicators for schools with subject specialists"
	gen byte sub`nyr'`yr'=both`yr'==0 & both`nyr'==0 & subsp`yr'==1 & subsp`nyr'==1

	foreach x in msam mtot esam etot {
		di "set information on math and english teachers to missing if subsp~=1"
		replace `x'`nyr'`yr'=. if subsp`yr'~=1 | subsp`nyr'~=1
		}

	di "create % of teachers who are same, by subject"
	gen pesa`nyr'`yr'=egsam`nyr'`yr'/egtot`nyr'`yr'
	gen pmsa`nyr'`yr'=mgsam`nyr'`yr'/mgtot`nyr'`yr'

	di "create % of teachers who gain experience, by subject"
	gen pegx`nyr'`yr'=eggx`nyr'`yr'/egtot`nyr'`yr'
	gen pmgx`nyr'`yr'=mggx`nyr'`yr'/mgtot`nyr'`yr'

	di "create change in % of teachers 0 yrs experience, by subject"
	gen echz`nyr'`yr'=abs(ezexdum`nyr'-ezexdum`yr')
	gen mchz`nyr'`yr'=abs(mzexdum`nyr'-mzexdum`yr')

	di "create change in % of teachers 1 yr experience, by subject"
	gen echo`nyr'`yr'=abs(eoexdum`nyr'-eoexdum`yr')
	gen mcho`nyr'`yr'=abs(moexdum`nyr'-moexdum`yr')

	di "set number of teachers to include general teachers, by subject"
	replace etot`nyr'`yr'=egtot`nyr'`yr'
	replace mtot`nyr'`yr'=mgtot`nyr'`yr'

	local yr = `yr'+1
	}

di "check data"

local yr1=93
while `yr1'<=96 {

	local yr2=`yr1'+1
	local yr3=`yr2'+1
	local gr=`yr2'-90

	foreach x in m e {
		gen dif`x'`yr3'`yr2'=`x'tot`yr3'`yr2'-`x'tot`yr2'`yr1' if `x'tot`yr3'`yr2'>0 & `x'tot`yr2'`yr1'>0
		}

	local yr1 =`yr1' + 1
	}

sum
sum dif*,detail

di "save data set"
sort campus grade
save ${rivkin_home}simba_e/texdata/Texas/teacher/turnov,replace

end
